@@ -10,7 +10,6 @@
 
 #include <QtTestWidgets>
 
-#include "script_test_base.h"
 #include "testutils.h"
 
 QTEST_MAIN(CommandsTest)
@@ -33,3 +32,5 @@ void CommandsTest::utils()
 {
     runTest(ExpectedFailures());
 }
+
+#include "moc_commands_test.cpp"
