@@ -7,7 +7,7 @@
 
 #include "completion_test.h"
 #include "codecompletiontestmodels.h"
-//#include "codecompletiontestmodels.moc"
+// #include "codecompletiontestmodels.moc"
 
 #include <ksycoca.h>
 
@@ -44,26 +44,12 @@ int countItems(KateCompletionModel *model)
 
 static void verifyCompletionStarted(KTextEditor::ViewPrivate *view)
 {
-    const QDateTime startTime = QDateTime::currentDateTime();
-    while (startTime.msecsTo(QDateTime::currentDateTime()) < 1000) {
-        QApplication::processEvents();
-        if (view->completionWidget()->isCompletionActive()) {
-            break;
-        }
-    }
-    QVERIFY(view->completionWidget()->isCompletionActive());
+    QTRY_VERIFY_WITH_TIMEOUT(view->completionWidget()->isCompletionActive(), 1000);
 }
 
 static void verifyCompletionAborted(KTextEditor::ViewPrivate *view)
 {
-    const QDateTime startTime = QDateTime::currentDateTime();
-    while (startTime.msecsTo(QDateTime::currentDateTime()) < 1000) {
-        QApplication::processEvents();
-        if (!view->completionWidget()->isCompletionActive()) {
-            break;
-        }
-    }
-    QVERIFY(!view->completionWidget()->isCompletionActive());
+    QTRY_VERIFY_WITH_TIMEOUT(!view->completionWidget()->isCompletionActive(), 1000);
 }
 
 static void invokeCompletionBox(KTextEditor::ViewPrivate *view)
@@ -414,26 +400,67 @@ void CompletionTest::testAutoCompletionPreselectFirst()
 
     verifyCompletionAborted(m_view);
     QCOMPARE(m_doc->text(), "a\n");
+}
 
-    // When no completion entry is selected, tab key should select the first entry
-    m_doc->setText("a");
-    m_view->completionWidget()->automaticInvocation();
-    m_view->completionWidget()->tab(false);
-    m_view->completionWidget()->execute();
+void CompletionTest::testTabCompletion()
+{
+    new CodeCompletionTestModel(m_view, QStringLiteral("a"));
 
-    QVERIFY(!m_view->completionWidget()->isCompletionActive());
-    QCOMPARE(m_doc->text(), "aaa0");
+    m_view->config()->setValue(KateViewConfig::TabCompletion, true);
 
-    // Ensure that auto completion still works when AutomaticCompletionPreselectFirst is enabled (default)
+    // First entry already selected
     m_view->config()->setValue(KateViewConfig::AutomaticCompletionPreselectFirst, true);
+
+    // Nothing to do, already selected
     m_doc->setText("a");
     m_view->completionWidget()->automaticInvocation();
-
-    m_view->completionWidget()->tab(false); // tab should "auto-fill" completion
-    QCOMPARE(m_doc->text(), "aa");
+    QVERIFY(m_view->completionWidget()->isCompletionActive());
     m_view->completionWidget()->execute();
-    QCOMPARE(m_doc->text(), "aaa0");
     QVERIFY(!m_view->completionWidget()->isCompletionActive());
+    QCOMPARE(m_doc->text(), "aaa0");
+
+    // First entry already selected, going down will select the next completion
+    m_doc->setText("a");
+    m_view->completionWidget()->automaticInvocation();
+    QVERIFY(m_view->completionWidget()->isCompletionActive());
+    m_view->completionWidget()->tabCompletion(KateCompletionWidget::Down);
+    m_view->completionWidget()->execute();
+    QVERIFY(!m_view->completionWidget()->isCompletionActive());
+    QCOMPARE(m_doc->text(), "aad3");
+
+    // First entry _not_ already selected...
+    m_view->config()->setValue(KateViewConfig::AutomaticCompletionPreselectFirst, false);
+
+    m_doc->setText("a");
+    m_view->completionWidget()->automaticInvocation();
+    QVERIFY(m_view->completionWidget()->isCompletionActive());
+    // ... Tab will select the first entry
+    m_view->completionWidget()->tabCompletion(KateCompletionWidget::Down);
+    m_view->completionWidget()->execute();
+    QVERIFY(!m_view->completionWidget()->isCompletionActive());
+    QCOMPARE(m_doc->text(), "aaa0");
+
+    // While at the top, going up, cycles to the bottom of the list
+    m_doc->setText("a");
+    m_view->completionWidget()->automaticInvocation();
+    QVERIFY(m_view->completionWidget()->isCompletionActive());
+    m_view->completionWidget()->cursorDown(); // Select first entry
+    m_view->completionWidget()->tabCompletion(KateCompletionWidget::Up);
+    m_view->completionWidget()->execute();
+    QVERIFY(!m_view->completionWidget()->isCompletionActive());
+    QCOMPARE(m_doc->text(), "ac\u008738");
+
+    // While at the bottom, going down cycles to the top of the list
+    m_doc->setText("a");
+    m_view->completionWidget()->automaticInvocation();
+    QVERIFY(m_view->completionWidget()->isCompletionActive());
+    m_view->completionWidget()->cursorDown(); // Select first entry
+    m_view->completionWidget()->tabCompletion(KateCompletionWidget::Up); // Go to bottom
+    // While at the bottom, Tab goes to the top of the list
+    m_view->completionWidget()->tabCompletion(KateCompletionWidget::Down);
+    m_view->completionWidget()->execute();
+    QVERIFY(!m_view->completionWidget()->isCompletionActive());
+    QCOMPARE(m_doc->text(), "aaa0");
 }
 
 void CompletionTest::benchAbbreviationEngineGoodCase()
@@ -482,7 +509,7 @@ void CompletionTest::testAbbrevAndContainsMatching()
 
     m_view->document()->setText(QStringLiteral("SC"));
     invokeCompletionBox(m_view);
-    QCOMPARE(model->filteredItemCount(), (uint)6);
+    QCOMPARE(model->filteredItemCount(), (uint)9);
 
     m_view->document()->setText(QStringLiteral("sca"));
     invokeCompletionBox(m_view);
@@ -490,20 +517,20 @@ void CompletionTest::testAbbrevAndContainsMatching()
 
     m_view->document()->setText(QStringLiteral("contains"));
     invokeCompletionBox(m_view);
-    QCOMPARE(model->filteredItemCount(), (uint)2);
+    QCOMPARE(model->filteredItemCount(), (uint)3);
 
     m_view->document()->setText(QStringLiteral("CONTAINS"));
     invokeCompletionBox(m_view);
-    QCOMPARE(model->filteredItemCount(), (uint)2);
+    QCOMPARE(model->filteredItemCount(), (uint)3);
 
     m_view->document()->setText(QStringLiteral("containssome"));
     invokeCompletionBox(m_view);
-    QCOMPARE(model->filteredItemCount(), (uint)1);
+    QCOMPARE(model->filteredItemCount(), (uint)2);
 
     m_view->document()->setText(QStringLiteral("matched"));
     m_view->userInvokedCompletion();
     QApplication::processEvents();
-    QCOMPARE(model->filteredItemCount(), (uint)0);
+    QCOMPARE(model->filteredItemCount(), (uint)1);
 }
 
 void CompletionTest::testAsyncMatching()
@@ -522,16 +549,17 @@ void CompletionTest::testAsyncMatching()
 
 void CompletionTest::benchCompletionModel()
 {
+    const int testFactor = 1;
     const QString text("abcdefg abcdef");
     m_doc->setText(text);
     CodeCompletionTestModel *testModel1 = new CodeCompletionTestModel(m_view, QStringLiteral("abcdefg"));
-    testModel1->setRowCount(500);
+    testModel1->setRowCount(50 * testFactor);
     CodeCompletionTestModel *testModel2 = new CodeCompletionTestModel(m_view, QStringLiteral("abcdef"));
-    testModel2->setRowCount(500);
+    testModel2->setRowCount(50 * testFactor);
     CodeCompletionTestModel *testModel3 = new CodeCompletionTestModel(m_view, QStringLiteral("abcde"));
-    testModel3->setRowCount(500);
+    testModel3->setRowCount(50 * testFactor);
     CodeCompletionTestModel *testModel4 = new CodeCompletionTestModel(m_view, QStringLiteral("abcd"));
-    testModel4->setRowCount(5000);
+    testModel4->setRowCount(500 * testFactor);
     QBENCHMARK_ONCE {
         for (int i = 0; i < text.size(); ++i) {
             m_view->setCursorPosition(Cursor(0, i));
@@ -539,3 +567,5 @@ void CompletionTest::benchCompletionModel()
         }
     }
 }
+
+#include "moc_completion_test.cpp"
