@@ -13,6 +13,9 @@
 // BEGIN Includes
 #include "indenttest.h"
 
+#include "kateconfig.h"
+#include "katedocument.h"
+
 #include <QtTestWidgets>
 
 #include "testutils.h"
@@ -24,6 +27,7 @@ QTEST_MAIN(IndentTest)
 void IndentTest::initTestCase()
 {
     ScriptTestBase::initTestCase();
+    m_document->config()->setValue(KateDocumentConfig::IndentOnTextPaste, true);
     m_section = "indent";
     m_script_dir = "indentation";
 }
@@ -56,9 +60,6 @@ void IndentTest::testCppstyle_data()
 
 void IndentTest::testCppstyle()
 {
-#if QT_VERSION <= QT_VERSION_CHECK(5, 15, 0)
-    QSKIP("This test crashes in Qt (QV4::MemoryManager::mark()), already fixed upstream");
-#endif
     runTest(ExpectedFailures()
             /// \todo Fix (smth) to make failed test cases really work!
             << FAILURE("parens1", "dunno why it failed in test! in manual mode everything works fine..."));
@@ -84,6 +85,16 @@ void IndentTest::testPython()
     runTest(ExpectedFailures());
 }
 
+void IndentTest::testJulia_data()
+{
+    getTestData("julia");
+}
+
+void IndentTest::testJulia()
+{
+    runTest(ExpectedFailures());
+}
+
 void IndentTest::testHaskell_data()
 {
     getTestData("haskell");
@@ -111,9 +122,6 @@ void IndentTest::testPascal_data()
 
 void IndentTest::testPascal()
 {
-#if QT_VERSION <= QT_VERSION_CHECK(5, 15, 0)
-    QSKIP("This test crashes in Qt (QV4::MemoryManager::mark()), already fixed upstream");
-#endif
     runTest(ExpectedFailures());
 }
 
@@ -124,9 +132,6 @@ void IndentTest::testAda_data()
 
 void IndentTest::testAda()
 {
-#if QT_VERSION <= QT_VERSION_CHECK(5, 15, 0)
-    QSKIP("This test crashes in Qt (QV4::MemoryManager::mark()), already fixed upstream");
-#endif
     runTest(ExpectedFailures());
 }
 
@@ -137,9 +142,6 @@ void IndentTest::testRuby_data()
 
 void IndentTest::testRuby()
 {
-#if QT_VERSION <= QT_VERSION_CHECK(5, 15, 0)
-    QSKIP("This test crashes in Qt (QV4::MemoryManager::mark()), already fixed upstream");
-#endif
     runTest(ExpectedFailures() << FAILURE("block01", "Multiline blocks using {} is not supported")
                                << FAILURE("block02", "Multiline blocks using {} is not supported")
                                << FAILURE("singleline01", "Single line defs are not supported") << FAILURE("singleline02", "Single line defs are not supported")
@@ -190,3 +192,5 @@ void IndentTest::testR()
 {
     runTest(ExpectedFailures());
 }
+
+#include "moc_indenttest.cpp"
