@@ -16,13 +16,15 @@ class MovingRangeTest : public QObject
 
 public:
     MovingRangeTest();
-    ~MovingRangeTest();
+    ~MovingRangeTest() override;
 
 private Q_SLOTS:
     void testFeedbackEmptyRange();
     void testFeedbackInvalidRange();
     void testFeedbackCaret();
     void testFeedbackMouse();
+    void testLineRemoved();
+    void testLineWrapOrUnwrapUpdateRangeForLineCache();
 };
 
 #endif // KATE_MOVINGRANGE_TEST_H
