@@ -1,22 +1,9 @@
-/*  This file is part of the KDE libraries and the Kate part.
- *
- *  Copyright (C) 2013-2016 Simon St James <kdedevel@etotheipiplusone.com>
- *
- *  This library is free software; you can redistribute it and/or
- *  modify it under the terms of the GNU Library General Public
- *  License as published by the Free Software Foundation; either
- *  version 2 of the License, or (at your option) any later version.
- *
- *  This library is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *  Library General Public License for more details.
- *
- *  You should have received a copy of the GNU Library General Public License
- *  along with this library; see the file COPYING.LIB.  If not, write to
- *  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- *  Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the KDE libraries and the Kate part.
+    SPDX-FileCopyrightText: 2013-2016 Simon St James <kdedevel@etotheipiplusone.com>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "emulatedcommandbarsetupandteardown.h"
 
@@ -28,6 +15,7 @@
 #include <QApplication>
 #include <QMainWindow>
 #include <QMetaObject>
+#include <QTest>
 
 // BEGIN: WindowKeepActive
 
@@ -69,6 +57,9 @@ EmulatedCommandBarSetUpAndTearDown::EmulatedCommandBarSetUpAndTearDown(KateViInp
     QApplication::processEvents();
     KateViewConfig::global()->setValue(KateViewConfig::ViInputModeStealKeys, true);
     m_window->installEventFilter(&m_windowKeepActive);
+
+    (void)QTest::qWaitForWindowExposed(m_view);
+    QTest::qWait(100); // For whatever reason needed
 }
 EmulatedCommandBarSetUpAndTearDown::~EmulatedCommandBarSetUpAndTearDown()
 {
@@ -82,3 +73,5 @@ EmulatedCommandBarSetUpAndTearDown::~EmulatedCommandBarSetUpAndTearDown()
 }
 
 // END: EmulatedCommandBarSetUpAndTearDown
+
+#include "moc_emulatedcommandbarsetupandteardown.cpp"
