@@ -174,6 +174,26 @@ void HlSearchTest::highlightModeTests()
         }
         FinishTest(text);
     }
+    // test highlighting when typing in search triggers a visual range change
+    {
+        QString text = "foo bar xyz\n\n\n\n\nfoo ab barx";
+        BeginTest(text);
+        auto vr = kate_view->visibleRange();
+        // ensure that last line is not visible
+        QVERIFY(vr.end().line() < 4);
+
+        TestPressKey("/barx");
+        {
+            QVector<Kate::TextRange *> ranges = rangesOnLine(0);
+            QCOMPARE(ranges.size(), rangesInitial.size());
+            ranges = rangesOnLine(5);
+            QCOMPARE(ranges.size(), rangesInitial.size() + 1);
+            TestHighlight(*ranges[0], {5, 7}, {5, 11}, searchHighlightColor);
+        }
+        TestPressKey("\\enter");
+
+        FinishTest(text);
+    }
     // test that normal search highlight is deactivated when hls mode is active
     {
         QString text = "foo bar xyz";
@@ -602,15 +622,44 @@ void HlSearchTest::highlightModeTests()
         }
         FinishTest(text);
     }
+    // test that newly inserted text will be highlighted
+    {
+        QString text = "foo xbar abcd bar";
+
+        TestPressKey("/xbar\\enter");
+        {
+            QVector<Kate::TextRange *> ranges = rangesOnLine(0);
+            QCOMPARE(ranges.size(), rangesInitial.size() + 1);
+            TestHighlight(*ranges[0], {0, 4}, {0, 8}, searchHighlightColor);
+        }
+        TestPressKey("wwix\\esc");
+        {
+            QVector<Kate::TextRange *> ranges = rangesOnLine(0);
+            QCOMPARE(ranges.size(), rangesInitial.size() + 2);
+            TestHighlight(*ranges[0], {0, 4}, {0, 8}, searchHighlightColor);
+            TestHighlight(*ranges[1], {0, 14}, {0, 18}, searchHighlightColor);
+        }
+
+        BeginTest(text);
+        FinishTest(text);
+    }
+    // test that no endless loop is triggered
+    {
+        QString text = "foo bar xyz\nabc def\nghi jkl\nmno pqr\nstu vwx\nfoo ab bar x";
+        BeginTest(text);
+        auto vr = kate_view->visibleRange();
+        // ensure that last line is not visible
+        QVERIFY(vr.end().line() < 4);
+
+        TestPressKey("/\\\\<\\enter");
+
+        FinishTest(text);
+    }
 }
 
 QVector<Kate::TextRange *> HlSearchTest::rangesOnLine(int line)
 {
-    return sortRanges(kate_document->buffer().rangesForLine(line, kate_view, true));
-}
-
-QVector<Kate::TextRange *> HlSearchTest::sortRanges(QVector<Kate::TextRange *> &&arr)
-{
+    QVector<Kate::TextRange *> arr = kate_document->buffer().rangesForLine(line, kate_view, true);
     std::sort(arr.begin(), arr.end(), [](const Kate::TextRange *l, const Kate::TextRange *r) {
         return l->toRange().start() < r->toRange().start();
     });
@@ -640,3 +689,5 @@ void HlSearchTest::TestHighlight_(int line, const char *file, const Kate::TextRa
     QTest::qCompare(r.end().line(), end[0], "end_line", "end_line", file, line);
     QTest::qCompare(r.end().column(), end[1], "end_column", "end_column", file, line);
 }
+
+#include "moc_hlsearch.cpp"
