@@ -10,6 +10,8 @@
 #include <inputmode/kateviinputmode.h>
 #include <katebuffer.h>
 #include <kateconfig.h>
+#include <katedocument.h>
+#include <kateview.h>
 
 using namespace KTextEditor;
 
@@ -20,11 +22,11 @@ void ViewTest::yankHighlightingTests()
     const QColor yankHighlightColour = kate_view->renderer()->config()->savedLineColor();
 
     BeginTest("foo bar xyz");
-    const QList<Kate::TextRange *> rangesInitial = rangesOnFirstLine();
+    const QVector<Kate::TextRange *> rangesInitial = rangesOnFirstLine();
     Q_ASSERT(rangesInitial.isEmpty() && "Assumptions about ranges are wrong - this test is invalid and may need updating!");
     TestPressKey("wyiw");
     {
-        const QList<Kate::TextRange *> rangesAfterYank = rangesOnFirstLine();
+        const QVector<Kate::TextRange *> rangesAfterYank = rangesOnFirstLine();
         QCOMPARE(rangesAfterYank.size(), rangesInitial.size() + 1);
         QCOMPARE(rangesAfterYank.first()->attribute()->background().color(), yankHighlightColour);
         QCOMPARE(rangesAfterYank.first()->start().line(), 0);
@@ -37,7 +39,7 @@ void ViewTest::yankHighlightingTests()
     BeginTest("foom bar xyz");
     TestPressKey("wY");
     {
-        const QList<Kate::TextRange *> rangesAfterYank = rangesOnFirstLine();
+        const QVector<Kate::TextRange *> rangesAfterYank = rangesOnFirstLine();
         QCOMPARE(rangesAfterYank.size(), rangesInitial.size() + 1);
         QCOMPARE(rangesAfterYank.first()->attribute()->background().color(), yankHighlightColour);
         QCOMPARE(rangesAfterYank.first()->start().line(), 0);
@@ -84,9 +86,7 @@ void ViewTest::visualLineUpDownTests()
     // Need to ensure we have dynamic wrap, a fixed width font, and a decent size kate_view.
     ensureKateViewVisible();
     const QFont oldFont = kate_view->renderer()->config()->baseFont();
-    QFont fixedWidthFont("Courier");
-    fixedWidthFont.setStyleHint(QFont::TypeWriter);
-    Q_ASSERT_X(QFontInfo(fixedWidthFont).fixedPitch(), "setting up visual line up down tests", "Need a fixed pitch font!");
+    QFont fixedWidthFont = QFontDatabase::systemFont(QFontDatabase::FixedFont);
     kate_view->renderer()->config()->setFont(fixedWidthFont);
     const bool oldDynWordWrap = KateViewConfig::global()->dynWordWrap();
     KateViewConfig::global()->setDynWordWrap(true);
@@ -180,7 +180,9 @@ void ViewTest::visualLineUpDownTests()
         const int numLinesToGoBackUp = 7;
         expectedText = startText;
         expectedText[((startVisualLine - 1) + numberLinesToGoDownInOneGo - numLinesToGoBackUp) * fillsLineAndEndsOnSpace.length()] = '.';
-        DoTest(startText, QString("gj").repeated(startVisualLine - 1) + QString::number(numberLinesToGoDownInOneGo) + "gj" + QString::number(numLinesToGoBackUp) + "gkr.", expectedText);
+        DoTest(startText,
+               QString("gj").repeated(startVisualLine - 1) + QString::number(numberLinesToGoDownInOneGo) + "gj" + QString::number(numLinesToGoBackUp) + "gkr.",
+               expectedText);
     }
 
     {
@@ -202,26 +204,36 @@ void ViewTest::visualLineUpDownTests()
         const QString unindentedFirstLine = "stickyhelper\n";
         const int numIndentationSpaces = 5;
         Q_ASSERT(textWrappingLength > numIndentationSpaces * 2 /* keep some wriggle room */);
-        const QString indentedFillsLineEndsOnSpace = QString(" ").repeated(numIndentationSpaces) + QString("X").repeated(textWrappingLength - 1 - numIndentationSpaces) + ' ';
-        DoTest(unindentedFirstLine + indentedFillsLineEndsOnSpace + "LINE3", QString("l").repeated(numIndentationSpaces) + "jgjr.", unindentedFirstLine + indentedFillsLineEndsOnSpace + ".INE3");
+        const QString indentedFillsLineEndsOnSpace =
+            QString(" ").repeated(numIndentationSpaces) + QString("X").repeated(textWrappingLength - 1 - numIndentationSpaces) + ' ';
+        DoTest(unindentedFirstLine + indentedFillsLineEndsOnSpace + "LINE3",
+               QString("l").repeated(numIndentationSpaces) + "jgjr.",
+               unindentedFirstLine + indentedFillsLineEndsOnSpace + ".INE3");
 
         // The first, non-wrapped portion of the line is not invisibly indented, though, so ensure we don't mess that up.
         QString expectedSecondLine = indentedFillsLineEndsOnSpace;
         expectedSecondLine[numIndentationSpaces] = '.';
-        DoTest(unindentedFirstLine + indentedFillsLineEndsOnSpace + "LINE3", QString("l").repeated(numIndentationSpaces) + "jgjgkr.", unindentedFirstLine + expectedSecondLine + "LINE3");
+        DoTest(unindentedFirstLine + indentedFillsLineEndsOnSpace + "LINE3",
+               QString("l").repeated(numIndentationSpaces) + "jgjgkr.",
+               unindentedFirstLine + expectedSecondLine + "LINE3");
     }
 
     {
         // Take into account any invisible indentation when setting the sticky column.
         const int numIndentationSpaces = 5;
         Q_ASSERT(textWrappingLength > numIndentationSpaces * 2 /* keep some wriggle room */);
-        const QString indentedFillsLineEndsOnSpace = QString(" ").repeated(numIndentationSpaces) + QString("X").repeated(textWrappingLength - 1 - numIndentationSpaces) + ' ';
+        const QString indentedFillsLineEndsOnSpace =
+            QString(" ").repeated(numIndentationSpaces) + QString("X").repeated(textWrappingLength - 1 - numIndentationSpaces) + ' ';
         const int posInSecondWrappedLineToChange = 3;
         QString expectedText = indentedFillsLineEndsOnSpace + fillsLineAndEndsOnSpace;
         expectedText[textWrappingLength + posInSecondWrappedLineToChange] = '.';
-        DoTest(indentedFillsLineEndsOnSpace + fillsLineAndEndsOnSpace, QString::number(textWrappingLength + posInSecondWrappedLineToChange) + "lgkgjr.", expectedText);
+        DoTest(indentedFillsLineEndsOnSpace + fillsLineAndEndsOnSpace,
+               QString::number(textWrappingLength + posInSecondWrappedLineToChange) + "lgkgjr.",
+               expectedText);
         // Make sure we can do this more than once (i.e. clear any flags that need clearing).
-        DoTest(indentedFillsLineEndsOnSpace + fillsLineAndEndsOnSpace, QString::number(textWrappingLength + posInSecondWrappedLineToChange) + "lgkgjr.", expectedText);
+        DoTest(indentedFillsLineEndsOnSpace + fillsLineAndEndsOnSpace,
+               QString::number(textWrappingLength + posInSecondWrappedLineToChange) + "lgkgjr.",
+               expectedText);
     }
 
     {
@@ -230,7 +242,9 @@ void ViewTest::visualLineUpDownTests()
         const int posInSecondWrappedLineToChange = 3;
         QString expectedText = indentedFillsLineEndsOnSpace + fillsLineAndEndsOnSpace;
         expectedText[textWrappingLength - tabWidth + posInSecondWrappedLineToChange] = '.';
-        DoTest(indentedFillsLineEndsOnSpace + fillsLineAndEndsOnSpace, QString("fXf ") + QString::number(posInSecondWrappedLineToChange) + "lgkgjr.", expectedText);
+        DoTest(indentedFillsLineEndsOnSpace + fillsLineAndEndsOnSpace,
+               QString("fXf ") + QString::number(posInSecondWrappedLineToChange) + "lgkgjr.",
+               expectedText);
     }
 
     {
@@ -281,7 +295,9 @@ void ViewTest::visualLineUpDownTests()
         const int posOnSecondLineToChange = 2;
         QString expectedSecondLine = beginsWithTabFillsLineEndsOnSpace;
         expectedSecondLine[posOnSecondLineToChange + 1 /* "+1" as we're not counting the leading tab as a pos */] = '.';
-        DoTest(unindentedFirstLine + beginsWithTabFillsLineEndsOnSpace + fillsLineAndEndsOnSpace, QString("l").repeated(tabWidth + posOnSecondLineToChange) + "gjgjgkr.", unindentedFirstLine + expectedSecondLine + fillsLineAndEndsOnSpace);
+        DoTest(unindentedFirstLine + beginsWithTabFillsLineEndsOnSpace + fillsLineAndEndsOnSpace,
+               QString("l").repeated(tabWidth + posOnSecondLineToChange) + "gjgjgkr.",
+               unindentedFirstLine + expectedSecondLine + fillsLineAndEndsOnSpace);
     }
 
     // Restore back to how we were before.
@@ -402,7 +418,9 @@ void ViewTest::clipboardTests()
     QCOMPARE(QApplication::clipboard()->text(), clipboard);
 }
 
-QList<Kate::TextRange *> ViewTest::rangesOnFirstLine()
+QVector<Kate::TextRange *> ViewTest::rangesOnFirstLine()
 {
     return kate_document->buffer().rangesForLine(0, kate_view, true);
 }
+
+#include "moc_view.cpp"
