@@ -1,28 +1,13 @@
 /*
- * <one line to give the library's name and an idea of what it does.>
- * Copyright 2013  Sven Brauch <svenbrauch@gmail.com>
+    SPDX-FileCopyrightText: 2013 Sven Brauch <svenbrauch@gmail.com>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "wordcompletiontest.h"
 
 #include <kateglobal.h>
 #include <katewordcompletion.h>
-#include <ktexteditor/document.h>
 #include <ktexteditor/editor.h>
 #include <ktexteditor/view.h>
 
@@ -112,3 +97,5 @@ void WordCompletionTest::benchWordRetrievalDistinct()
         QCOMPARE(m.allMatches(v.data(), KTextEditor::Range()).size(), count);
     }
 }
+
+#include "moc_wordcompletiontest.cpp"
