@@ -8,10 +8,8 @@
 #include "katecompletionmodel.h"
 
 #include "kateargumenthintmodel.h"
-#include "katecompletiondelegate.h"
 #include "katecompletiontree.h"
 #include "katecompletionwidget.h"
-#include "kateconfig.h"
 #include "katepartdebug.h"
 #include "katerenderer.h"
 #include "kateview.h"
@@ -22,7 +20,6 @@
 
 #include <QApplication>
 #include <QMultiMap>
-#include <QTextEdit>
 #include <QTimer>
 #include <QVarLengthArray>
 
@@ -93,12 +90,12 @@ int HierarchicalModelHandler::inheritanceDepth(const QModelIndex &i) const
 void HierarchicalModelHandler::takeRole(const QModelIndex &index)
 {
     QVariant v = index.data(CodeCompletionModel::GroupRole);
-    if (v.isValid() && v.canConvert(QVariant::Int)) {
+    if (v.isValid() && v.canConvert<int>()) {
         QVariant value = index.data(v.toInt());
         if (v.toInt() == Qt::DisplayRole) {
             m_customGroup = index.data(Qt::DisplayRole).toString();
             QVariant sortingKey = index.data(CodeCompletionModel::InheritanceDepth);
-            if (sortingKey.canConvert(QVariant::Int)) {
+            if (sortingKey.canConvert<int>()) {
                 m_groupSortingKey = sortingKey.toInt();
             }
         } else {
@@ -147,6 +144,14 @@ KateCompletionModel::KateCompletionModel(KateCompletionWidget *parent)
     m_groupHash.insert(0, m_ungrouped);
     m_groupHash.insert(-1, m_argumentHints);
     m_groupHash.insert(BestMatchesProperty, m_argumentHints);
+
+    QList<QList<int>> mergedColumns;
+    mergedColumns << (QList<int>() << 0);
+    mergedColumns << (QList<int>() << 1 << 2 << 3 << 4);
+    mergedColumns << (QList<int>() << 5);
+    m_columnMerges = mergedColumns;
+
+    createGroups();
 }
 
 KateCompletionModel::~KateCompletionModel()
@@ -176,26 +181,21 @@ QVariant KateCompletionModel::data(const QModelIndex &index, int role) const
     // groupOfParent returns a group when the index is a member of that group, but not the group head/label.
     if (!hasGroups() || groupOfParent(index)) {
         if (role == Qt::TextAlignmentRole) {
-            if (isColumnMergingEnabled() && !m_columnMerges.isEmpty()) {
-                int c = 0;
-                for (const QList<int> &list : std::as_const(m_columnMerges)) {
-                    if (index.column() < c + list.size()) {
-                        c += list.size();
-                        continue;
-                    } else if (list.count() == 1 && list.first() == CodeCompletionModel::Scope) {
-                        return Qt::AlignRight;
-                    } else {
-                        return QVariant();
-                    }
+            int c = 0;
+            for (const QList<int> &list : std::as_const(m_columnMerges)) {
+                if (index.column() < c + list.size()) {
+                    c += list.size();
+                    continue;
+                } else if (list.count() == 1 && list.first() == CodeCompletionModel::Scope) {
+                    return Qt::AlignRight;
+                } else {
+                    return QVariant();
                 }
-
-            } else if ((!isColumnMergingEnabled() || m_columnMerges.isEmpty()) && index.column() == CodeCompletionModel::Scope) {
-                return Qt::AlignRight;
             }
         }
 
         // Merge text for column merging
-        if (role == Qt::DisplayRole && !m_columnMerges.isEmpty() && isColumnMergingEnabled()) {
+        if (role == Qt::DisplayRole) {
             QString text;
             for (int column : m_columnMerges[index.column()]) {
                 QModelIndex sourceIndex = mapToSource(createIndex(index.row(), column, index.internalPointer()));
@@ -357,10 +357,10 @@ KTextEditor::ViewPrivate *KateCompletionModel::view() const
 
 int KateCompletionModel::columnCount(const QModelIndex &) const
 {
-    return isColumnMergingEnabled() && !m_columnMerges.isEmpty() ? m_columnMerges.count() : KTextEditor::CodeCompletionModel::ColumnCount;
+    return 3;
 }
 
-KateCompletionModel::ModelRow KateCompletionModel::modelRowPair(const QModelIndex &index) const
+KateCompletionModel::ModelRow KateCompletionModel::modelRowPair(const QModelIndex &index)
 {
     return qMakePair(static_cast<CodeCompletionModel *>(const_cast<QAbstractItemModel *>(index.model())), index);
 }
@@ -429,30 +429,6 @@ QModelIndex KateCompletionModel::index(int row, int column, const QModelIndex &p
     return createIndex(row, column, quintptr(0));
 }
 
-/*QModelIndex KateCompletionModel::sibling( int row, int column, const QModelIndex & index ) const
-{
-  if (row < 0 || column < 0 || column >= columnCount(QModelIndex()))
-    return QModelIndex();
-
-  if (!index.isValid()) {
-  }
-
-  if (Group* g = groupOfParent(index)) {
-    if (row >= g->filtered.count())
-      return QModelIndex();
-
-    return createIndex(row, column, g);
-  }
-
-  if (hasGroups())
-    return QModelIndex();
-
-  if (row >= m_ungrouped->filtered.count())
-    return QModelIndex();
-
-  return createIndex(row, column, m_ungrouped);
-}*/
-
 bool KateCompletionModel::hasIndex(int row, int column, const QModelIndex &parent) const
 {
     if (row < 0 || column < 0 || column >= columnCount(QModelIndex())) {
@@ -537,10 +513,10 @@ void KateCompletionModel::clearGroups()
     m_groupHash.insert(BestMatchesProperty, m_bestMatches);
 }
 
-QSet<KateCompletionModel::Group *> KateCompletionModel::createItems(const HierarchicalModelHandler &_handler, const QModelIndex &i, bool notifyModel)
+KateCompletionModel::GroupSet KateCompletionModel::createItems(const HierarchicalModelHandler &_handler, const QModelIndex &i, bool notifyModel)
 {
     HierarchicalModelHandler handler(_handler);
-    QSet<Group *> ret;
+    GroupSet ret;
     QAbstractItemModel *model = handler.model();
 
     if (model->rowCount(i) == 0) {
@@ -550,16 +526,16 @@ QSet<KateCompletionModel::Group *> KateCompletionModel::createItems(const Hierar
         // Non-leaf node, take the role from the node, and recurse to the sub-nodes
         handler.takeRole(i);
         for (int a = 0; a < model->rowCount(i); a++) {
-            ret += createItems(handler, model->index(a, 0, i), notifyModel);
+            ret.merge(createItems(handler, model->index(a, 0, i), notifyModel));
         }
     }
 
     return ret;
 }
 
-QSet<KateCompletionModel::Group *> KateCompletionModel::deleteItems(const QModelIndex &i)
+KateCompletionModel::GroupSet KateCompletionModel::deleteItems(const QModelIndex &i)
 {
-    QSet<Group *> ret;
+    GroupSet ret;
 
     if (i.model()->rowCount(i) == 0) {
         // Leaf node, delete the item
@@ -569,7 +545,7 @@ QSet<KateCompletionModel::Group *> KateCompletionModel::deleteItems(const QModel
     } else {
         // Non-leaf node
         for (int a = 0; a < i.model()->rowCount(i); a++) {
-            ret += deleteItems(i.model()->index(a, 0, i));
+            ret.merge(deleteItems(i.model()->index(a, 0, i)));
         }
     }
 
@@ -583,20 +559,21 @@ void KateCompletionModel::createGroups()
     // new groups.
     clearGroups();
 
-    QSet<Group *> groups;
-
     bool has_groups = false;
+    GroupSet groups;
     for (CodeCompletionModel *sourceModel : std::as_const(m_completionModels)) {
         has_groups |= sourceModel->hasGroups();
         for (int i = 0; i < sourceModel->rowCount(); ++i) {
-            groups += createItems(HierarchicalModelHandler(sourceModel), sourceModel->index(i, 0));
+            groups.merge(createItems(HierarchicalModelHandler(sourceModel), sourceModel->index(i, 0)));
         }
     }
 
     // since notifyModel = false above, we just appended the data as is,
     // we sort it now
     for (auto g : groups) {
-        std::sort(g->prefilter.begin(), g->prefilter.end());
+        // no need to sort prefiltered, it is just the raw dump of everything
+        // filtered is what gets displayed
+        //         std::sort(g->prefilter.begin(), g->prefilter.end());
         std::sort(g->filtered.begin(), g->filtered.end());
     }
 
@@ -624,10 +601,6 @@ KateCompletionModel::Group *KateCompletionModel::createItem(const HierarchicalMo
 
     int completionFlags = handler.getData(CodeCompletionModel::CompletionRole, sourceIndex).toInt();
 
-    // Scope is expensive, should not be used with big models
-    QString scopeIfNeeded =
-        (groupingMethod() & Scope) ? sourceIndex.sibling(sourceIndex.row(), CodeCompletionModel::Scope).data(Qt::DisplayRole).toString() : QString();
-
     int argumentHintDepth = handler.getData(CodeCompletionModel::ArgumentHintDepth, sourceIndex).toInt();
 
     Group *g;
@@ -645,7 +618,7 @@ KateCompletionModel::Group *KateCompletionModel::createItem(const HierarchicalMo
                 m_customGroupHash.insert(customGroup, g);
             }
         } else {
-            g = fetchGroup(completionFlags, scopeIfNeeded, handler.hasHierarchicalRoles());
+            g = fetchGroup(completionFlags, handler.hasHierarchicalRoles());
         }
     }
 
@@ -662,18 +635,17 @@ KateCompletionModel::Group *KateCompletionModel::createItem(const HierarchicalMo
 
 void KateCompletionModel::slotRowsInserted(const QModelIndex &parent, int start, int end)
 {
-
     HierarchicalModelHandler handler(static_cast<CodeCompletionModel *>(sender()));
     if (parent.isValid()) {
         handler.collectRoles(parent);
     }
 
-    QSet<Group *> affectedGroups;
+    GroupSet affectedGroups;
     for (int i = start; i <= end; ++i) {
-        affectedGroups += createItems(handler, handler.model()->index(i, 0, parent), /* notifyModel= */ true);
+        affectedGroups.merge(createItems(handler, handler.model()->index(i, 0, parent), /* notifyModel= */ true));
     }
 
-    for (Group *g : std::as_const(affectedGroups)) {
+    for (auto g : affectedGroups) {
         hideOrShowGroup(g, true);
     }
 }
@@ -682,20 +654,18 @@ void KateCompletionModel::slotRowsRemoved(const QModelIndex &parent, int start,
 {
     CodeCompletionModel *source = static_cast<CodeCompletionModel *>(sender());
 
-    QSet<Group *> affectedGroups;
-
+    GroupSet affectedGroups;
     for (int i = start; i <= end; ++i) {
         QModelIndex index = source->index(i, 0, parent);
-
-        affectedGroups += deleteItems(index);
+        affectedGroups.merge(deleteItems(index));
     }
 
-    for (Group *g : std::as_const(affectedGroups)) {
+    for (auto g : affectedGroups) {
         hideOrShowGroup(g, true);
     }
 }
 
-KateCompletionModel::Group *KateCompletionModel::fetchGroup(int attribute, const QString &scope, bool forceGrouping)
+KateCompletionModel::Group *KateCompletionModel::fetchGroup(int attribute, bool forceGrouping)
 {
     Q_UNUSED(forceGrouping);
 
@@ -708,15 +678,7 @@ KateCompletionModel::Group *KateCompletionModel::fetchGroup(int attribute, const
     // qCDebug(LOG_KTE) << attribute << " " << groupingAttribute;
 
     if (m_groupHash.contains(groupingAttribute)) {
-        if (groupingMethod() & Scope) {
-            for (auto it = m_groupHash.constFind(groupingAttribute); it != m_groupHash.constEnd() && it.key() == groupingAttribute; ++it) {
-                if (it.value()->scope == scope) {
-                    return it.value();
-                }
-            }
-        } else {
-            return m_groupHash.value(groupingAttribute);
-        }
+        return m_groupHash.value(groupingAttribute);
     }
 
     QString st;
@@ -724,80 +686,34 @@ KateCompletionModel::Group *KateCompletionModel::fetchGroup(int attribute, const
     QString it;
     QString title;
 
-    if (groupingMethod() & ScopeType) {
-        if (attribute & KTextEditor::CodeCompletionModel::GlobalScope) {
-            st = QStringLiteral("Global");
-        } else if (attribute & KTextEditor::CodeCompletionModel::NamespaceScope) {
-            st = QStringLiteral("Namespace");
-        } else if (attribute & KTextEditor::CodeCompletionModel::LocalScope) {
-            st = QStringLiteral("Local");
-        }
-
-        title = st;
+    if (attribute & KTextEditor::CodeCompletionModel::GlobalScope) {
+        st = QStringLiteral("Global");
+    } else if (attribute & KTextEditor::CodeCompletionModel::NamespaceScope) {
+        st = QStringLiteral("Namespace");
+    } else if (attribute & KTextEditor::CodeCompletionModel::LocalScope) {
+        st = QStringLiteral("Local");
     }
 
-    if (groupingMethod() & Scope) {
+    title = st;
+
+    if (attribute & KTextEditor::CodeCompletionModel::Public) {
+        at = QStringLiteral("Public");
+    } else if (attribute & KTextEditor::CodeCompletionModel::Protected) {
+        at = QStringLiteral("Protected");
+    } else if (attribute & KTextEditor::CodeCompletionModel::Private) {
+        at = QStringLiteral("Private");
+    }
+
+    if (!at.isEmpty()) {
         if (!title.isEmpty()) {
-            title.append(QLatin1Char(' '));
+            title.append(QLatin1String(", "));
         }
 
-        title.append(scope);
-    }
-
-    if (groupingMethod() & AccessType) {
-        if (attribute & KTextEditor::CodeCompletionModel::Public) {
-            at = QStringLiteral("Public");
-        } else if (attribute & KTextEditor::CodeCompletionModel::Protected) {
-            at = QStringLiteral("Protected");
-        } else if (attribute & KTextEditor::CodeCompletionModel::Private) {
-            at = QStringLiteral("Private");
-        }
-
-        if (accessIncludeStatic() && attribute & KTextEditor::CodeCompletionModel::Static) {
-            at.append(QLatin1String(" Static"));
-        }
-
-        if (accessIncludeConst() && attribute & KTextEditor::CodeCompletionModel::Const) {
-            at.append(QLatin1String(" Const"));
-        }
-
-        if (!at.isEmpty()) {
-            if (!title.isEmpty()) {
-                title.append(QLatin1String(", "));
-            }
-
-            title.append(at);
-        }
-    }
-
-    if (groupingMethod() & ItemType) {
-        if (attribute & CodeCompletionModel::Namespace) {
-            it = i18n("Namespaces");
-        } else if (attribute & CodeCompletionModel::Class) {
-            it = i18n("Classes");
-        } else if (attribute & CodeCompletionModel::Struct) {
-            it = i18n("Structs");
-        } else if (attribute & CodeCompletionModel::Union) {
-            it = i18n("Unions");
-        } else if (attribute & CodeCompletionModel::Function) {
-            it = i18n("Functions");
-        } else if (attribute & CodeCompletionModel::Variable) {
-            it = i18n("Variables");
-        } else if (attribute & CodeCompletionModel::Enum) {
-            it = i18n("Enumerations");
-        }
-
-        if (!it.isEmpty()) {
-            if (!title.isEmpty()) {
-                title.append(QLatin1Char(' '));
-            }
-
-            title.append(it);
-        }
+        title.append(at);
     }
 
     Group *ret = new Group(title, attribute, this);
-    ret->scope = scope;
+    ret->scope = QString();
 
     m_emptyGroups.append(ret);
     m_groupHash.insert(groupingAttribute, ret);
@@ -813,7 +729,7 @@ bool KateCompletionModel::hasGroups() const
     // be populated with a delay from within a background-thread.
     // Proper solution: Ask all attached code-models(Through a new interface) whether they want to use grouping,
     // and if at least one wants to, return true, else return false.
-    return m_groupingEnabled && m_hasGroups;
+    return m_hasGroups;
 }
 
 KateCompletionModel::Group *KateCompletionModel::groupForIndex(const QModelIndex &index) const
@@ -837,17 +753,6 @@ KateCompletionModel::Group *KateCompletionModel::groupForIndex(const QModelIndex
     return m_rowTable[index.row()];
 }
 
-/*QMap< int, QVariant > KateCompletionModel::itemData( const QModelIndex & index ) const
-{
-  if (!hasGroups() || groupOfParent(index)) {
-    QModelIndex index = mapToSource(index);
-    if (index.isValid())
-      return index.model()->itemData(index);
-  }
-
-  return QAbstractItemModel::itemData(index);
-}*/
-
 QModelIndex KateCompletionModel::parent(const QModelIndex &index) const
 {
     if (!index.isValid()) {
@@ -901,12 +806,6 @@ int KateCompletionModel::rowCount(const QModelIndex &parent) const
     return g->filtered.size();
 }
 
-void KateCompletionModel::sort(int column, Qt::SortOrder order)
-{
-    Q_UNUSED(column)
-    Q_UNUSED(order)
-}
-
 QModelIndex KateCompletionModel::mapToSource(const QModelIndex &proxyIndex) const
 {
     if (!proxyIndex.isValid()) {
@@ -914,6 +813,11 @@ QModelIndex KateCompletionModel::mapToSource(const QModelIndex &proxyIndex) cons
     }
 
     if (Group *g = groupOfParent(proxyIndex)) {
+        if (!m_rowTable.contains(g)) {
+            qWarning() << Q_FUNC_INFO << "Stale proxy index for which there is no group";
+            return {};
+        }
+
         if (proxyIndex.row() >= 0 && proxyIndex.row() < (int)g->filtered.size()) {
             ModelRow source = g->filtered[proxyIndex.row()].sourceRow();
             return source.second.sibling(source.second.row(), proxyIndex.column());
@@ -953,49 +857,23 @@ QModelIndex KateCompletionModel::mapFromSource(const QModelIndex &sourceIndex) c
     return QModelIndex();
 }
 
-void KateCompletionModel::setCurrentCompletion(KTextEditor::CodeCompletionModel *model, const QString &completion)
+void KateCompletionModel::setCurrentCompletion(QMap<KTextEditor::CodeCompletionModel *, QString> currentMatch)
 {
-    auto &current = m_currentMatch[model];
-    if (current == completion) {
-        return;
-    }
+    beginResetModel();
 
-    if (!hasCompletionModel()) {
-        current = completion;
-        return;
-    }
-
-    changeTypes changeType = Change;
-
-    if (current.length() > completion.length() && current.startsWith(completion, Qt::CaseInsensitive)) {
-        // Filter has been broadened
-        changeType = Broaden;
-
-    } else if (current.length() < completion.length() && completion.startsWith(current, Qt::CaseInsensitive)) {
-        // Filter has been narrowed
-        changeType = Narrow;
-    }
-
-    // qCDebug(LOG_KTE) << model << "Old match: " << current << ", new: " << completion << ", type: " << changeType;
-
-    current = completion;
-
-    const bool resetModel = (changeType != Narrow);
-    if (resetModel) {
-        beginResetModel();
-    }
+    m_currentMatch = currentMatch;
 
     if (!hasGroups()) {
-        changeCompletions(m_ungrouped, changeType, !resetModel);
+        changeCompletions(m_ungrouped);
     } else {
         for (Group *g : std::as_const(m_rowTable)) {
             if (g != m_argumentHints) {
-                changeCompletions(g, changeType, !resetModel);
+                changeCompletions(g);
             }
         }
         for (Group *g : std::as_const(m_emptyGroups)) {
             if (g != m_argumentHints) {
-                changeCompletions(g, changeType, !resetModel);
+                changeCompletions(g);
             }
         }
     }
@@ -1003,11 +881,7 @@ void KateCompletionModel::setCurrentCompletion(KTextEditor::CodeCompletionModel
     // NOTE: best matches are also updated in resort
     resort();
 
-    if (resetModel) {
-        endResetModel();
-    }
-
-    Q_EMIT layoutChanged();
+    endResetModel();
 }
 
 QString KateCompletionModel::commonPrefixInternal(const QString &forcePrefix) const
@@ -1070,46 +944,16 @@ QString KateCompletionModel::commonPrefix(QModelIndex selectedIndex) const
     return commonPrefix;
 }
 
-void KateCompletionModel::changeCompletions(Group *g, changeTypes changeType, bool notifyModel)
+void KateCompletionModel::changeCompletions(Group *g)
 {
-    if (changeType != Narrow) {
-        g->filtered = g->prefilter;
-        // In the "Broaden" or "Change" case, just re-filter everything,
-        // and don't notify the model. The model is notified afterwards through a reset().
-    }
+    // This code determines what of the filtered items still fit
+    // don't notify the model. The model is notified afterwards through a reset().
+    g->filtered.clear();
+    std::remove_copy_if(g->prefilter.begin(), g->prefilter.end(), std::back_inserter(g->filtered), [](Item &item) {
+        return !item.match();
+    });
 
-    // This code determines what of the filtered items still fit, and computes the ranges that were removed, giving
-    // them to beginRemoveRows(..) in batches
-
-    std::vector<KateCompletionModel::Item> newFiltered;
-    int deleteUntil = -1; // In each state, the range [currentRow+1, deleteUntil] needs to be deleted
-    auto &filtered = g->filtered;
-    newFiltered.reserve(filtered.size());
-    for (int currentRow = filtered.size() - 1; currentRow >= 0; --currentRow) {
-        if (filtered[currentRow].match()) {
-            // This row does not need to be deleted, which means that currentRow+1 to deleteUntil need to be deleted now
-            if (deleteUntil != -1 && notifyModel) {
-                beginRemoveRows(indexForGroup(g), currentRow + 1, deleteUntil);
-                endRemoveRows();
-            }
-            deleteUntil = -1;
-
-            newFiltered.push_back(std::move(filtered[currentRow]));
-        } else {
-            if (deleteUntil == -1) {
-                deleteUntil = currentRow; // Mark that this row needs to be deleted
-            }
-        }
-    }
-
-    if (deleteUntil != -1 && notifyModel) {
-        beginRemoveRows(indexForGroup(g), 0, deleteUntil);
-        endRemoveRows();
-    }
-
-    std::reverse(newFiltered.begin(), newFiltered.end());
-    g->filtered = std::move(newFiltered);
-    hideOrShowGroup(g, notifyModel);
+    hideOrShowGroup(g, /*notifyModel=*/false);
 }
 
 int KateCompletionModel::Group::orderNumber() const
@@ -1242,40 +1086,6 @@ bool KateCompletionModel::hasCompletionModel() const
     return !m_completionModels.isEmpty();
 }
 
-void KateCompletionModel::setGroupingEnabled(bool enable)
-{
-    m_groupingEnabled = enable;
-}
-
-void KateCompletionModel::setColumnMergingEnabled(bool enable)
-{
-    if (m_columnMergingEnabled != enable) {
-        m_columnMergingEnabled = enable;
-    }
-}
-
-bool KateCompletionModel::isColumnMergingEnabled() const
-{
-    return m_columnMergingEnabled;
-}
-
-bool KateCompletionModel::isGroupingEnabled() const
-{
-    return m_groupingEnabled;
-}
-
-const QList<QList<int>> &KateCompletionModel::columnMerges() const
-{
-    return m_columnMerges;
-}
-
-void KateCompletionModel::setColumnMerges(const QList<QList<int>> &columnMerges)
-{
-    beginResetModel();
-    m_columnMerges = columnMerges;
-    endResetModel();
-}
-
 int KateCompletionModel::translateColumn(int sourceColumn) const
 {
     if (m_columnMerges.isEmpty()) {
@@ -1311,127 +1121,32 @@ int KateCompletionModel::groupingAttributes(int attribute) const
 {
     int ret = 0;
 
-    if (m_groupingMethod & ScopeType) {
-        if (countBits(attribute & ScopeTypeMask) > 1) {
-            qCWarning(LOG_KTE) << "Invalid completion model metadata: more than one scope type modifier provided.";
-        }
-
-        if (attribute & KTextEditor::CodeCompletionModel::GlobalScope) {
-            ret |= KTextEditor::CodeCompletionModel::GlobalScope;
-        } else if (attribute & KTextEditor::CodeCompletionModel::NamespaceScope) {
-            ret |= KTextEditor::CodeCompletionModel::NamespaceScope;
-        } else if (attribute & KTextEditor::CodeCompletionModel::LocalScope) {
-            ret |= KTextEditor::CodeCompletionModel::LocalScope;
-        }
+    if (countBits(attribute & ScopeTypeMask) > 1) {
+        qCWarning(LOG_KTE) << "Invalid completion model metadata: more than one scope type modifier provided.";
+    }
+    if (attribute & KTextEditor::CodeCompletionModel::GlobalScope) {
+        ret |= KTextEditor::CodeCompletionModel::GlobalScope;
+    } else if (attribute & KTextEditor::CodeCompletionModel::NamespaceScope) {
+        ret |= KTextEditor::CodeCompletionModel::NamespaceScope;
+    } else if (attribute & KTextEditor::CodeCompletionModel::LocalScope) {
+        ret |= KTextEditor::CodeCompletionModel::LocalScope;
     }
 
-    if (m_groupingMethod & AccessType) {
-        if (countBits(attribute & AccessTypeMask) > 1) {
-            qCWarning(LOG_KTE) << "Invalid completion model metadata: more than one access type modifier provided.";
-        }
-
-        if (attribute & KTextEditor::CodeCompletionModel::Public) {
-            ret |= KTextEditor::CodeCompletionModel::Public;
-        } else if (attribute & KTextEditor::CodeCompletionModel::Protected) {
-            ret |= KTextEditor::CodeCompletionModel::Protected;
-        } else if (attribute & KTextEditor::CodeCompletionModel::Private) {
-            ret |= KTextEditor::CodeCompletionModel::Private;
-        }
-
-        if (accessIncludeStatic() && attribute & KTextEditor::CodeCompletionModel::Static) {
-            ret |= KTextEditor::CodeCompletionModel::Static;
-        }
-
-        if (accessIncludeConst() && attribute & KTextEditor::CodeCompletionModel::Const) {
-            ret |= KTextEditor::CodeCompletionModel::Const;
-        }
+    if (countBits(attribute & AccessTypeMask) > 1) {
+        qCWarning(LOG_KTE) << "Invalid completion model metadata: more than one access type modifier provided.";
     }
-
-    if (m_groupingMethod & ItemType) {
-        if (countBits(attribute & ItemTypeMask) > 1) {
-            qCWarning(LOG_KTE) << "Invalid completion model metadata: more than one item type modifier provided.";
-        }
-
-        if (attribute & KTextEditor::CodeCompletionModel::Namespace) {
-            ret |= KTextEditor::CodeCompletionModel::Namespace;
-        } else if (attribute & KTextEditor::CodeCompletionModel::Class) {
-            ret |= KTextEditor::CodeCompletionModel::Class;
-        } else if (attribute & KTextEditor::CodeCompletionModel::Struct) {
-            ret |= KTextEditor::CodeCompletionModel::Struct;
-        } else if (attribute & KTextEditor::CodeCompletionModel::Union) {
-            ret |= KTextEditor::CodeCompletionModel::Union;
-        } else if (attribute & KTextEditor::CodeCompletionModel::Function) {
-            ret |= KTextEditor::CodeCompletionModel::Function;
-        } else if (attribute & KTextEditor::CodeCompletionModel::Variable) {
-            ret |= KTextEditor::CodeCompletionModel::Variable;
-        } else if (attribute & KTextEditor::CodeCompletionModel::Enum) {
-            ret |= KTextEditor::CodeCompletionModel::Enum;
-        }
-
-        /*
-        if (itemIncludeTemplate() && attribute & KTextEditor::CodeCompletionModel::Template)
-          ret |= KTextEditor::CodeCompletionModel::Template;*/
+    if (attribute & KTextEditor::CodeCompletionModel::Public) {
+        ret |= KTextEditor::CodeCompletionModel::Public;
+    } else if (attribute & KTextEditor::CodeCompletionModel::Protected) {
+        ret |= KTextEditor::CodeCompletionModel::Protected;
+    } else if (attribute & KTextEditor::CodeCompletionModel::Private) {
+        ret |= KTextEditor::CodeCompletionModel::Private;
     }
 
     return ret;
 }
 
-void KateCompletionModel::setGroupingMethod(GroupingMethods m)
-{
-    m_groupingMethod = m;
-
-    createGroups();
-}
-
-bool KateCompletionModel::accessIncludeConst() const
-{
-    return m_accessConst;
-}
-
-void KateCompletionModel::setAccessIncludeConst(bool include)
-{
-    if (m_accessConst != include) {
-        m_accessConst = include;
-
-        if (groupingMethod() & AccessType) {
-            createGroups();
-        }
-    }
-}
-
-bool KateCompletionModel::accessIncludeStatic() const
-{
-    return m_accessStatic;
-}
-
-void KateCompletionModel::setAccessIncludeStatic(bool include)
-{
-    if (m_accessStatic != include) {
-        m_accessStatic = include;
-
-        if (groupingMethod() & AccessType) {
-            createGroups();
-        }
-    }
-}
-
-bool KateCompletionModel::accessIncludeSignalSlot() const
-{
-    return m_accesSignalSlot;
-}
-
-void KateCompletionModel::setAccessIncludeSignalSlot(bool include)
-{
-    if (m_accesSignalSlot != include) {
-        m_accesSignalSlot = include;
-
-        if (groupingMethod() & AccessType) {
-            createGroups();
-        }
-    }
-}
-
-int KateCompletionModel::countBits(int value) const
+int KateCompletionModel::countBits(int value)
 {
     int count = 0;
     for (int i = 1; i; i <<= 1) {
@@ -1443,11 +1158,6 @@ int KateCompletionModel::countBits(int value) const
     return count;
 }
 
-KateCompletionModel::GroupingMethods KateCompletionModel::groupingMethod() const
-{
-    return m_groupingMethod;
-}
-
 KateCompletionModel::Item::Item(bool doInitialMatch, KateCompletionModel *m, const HierarchicalModelHandler &handler, ModelRow sr)
     : model(m)
     , m_sourceRow(sr)
@@ -1640,7 +1350,7 @@ bool KateCompletionModel::shouldMatchHideCompletionList() const
         for (const Item &item : std::as_const(group->filtered)) {
             if (item.haveExactMatch()) {
                 KTextEditor::CodeCompletionModelControllerInterface *iface3 =
-                    dynamic_cast<KTextEditor::CodeCompletionModelControllerInterface *>(item.sourceRow().first);
+                    qobject_cast<KTextEditor::CodeCompletionModelControllerInterface *>(item.sourceRow().first);
                 bool hide = false;
                 if (!iface3) {
                     hide = true;
@@ -1734,7 +1444,7 @@ static inline bool containsAtWordBeginning(const QString &word, const QString &t
 
 KateCompletionModel::Item::MatchType KateCompletionModel::Item::match()
 {
-    QString match = model->currentCompletion(m_sourceRow.first);
+    const QString match = model->currentCompletion(m_sourceRow.first);
 
     m_haveExactMatch = false;
 
@@ -1767,6 +1477,12 @@ KateCompletionModel::Item::MatchType KateCompletionModel::Item::match()
         }
     }
 
+    if (matchCompletion == NoMatch) {
+        if (m_nameColumn.contains(match, Qt::CaseInsensitive)) {
+            matchCompletion = ContainsMatch;
+        }
+    }
+
     if (matchCompletion && match.length() == m_nameColumn.length()) {
         matchCompletion = PerfectMatch;
         m_haveExactMatch = true;
@@ -1842,7 +1558,11 @@ void KateCompletionModel::removeCompletionModel(CodeCompletionModel *model)
         return;
     }
 
-    beginResetModel();
+    bool willCreateGroups = (m_completionModels.size() - 1) > 0;
+
+    if (!willCreateGroups) {
+        beginResetModel();
+    }
     m_currentMatch.remove(model);
 
     clearGroups();
@@ -1850,9 +1570,11 @@ void KateCompletionModel::removeCompletionModel(CodeCompletionModel *model)
     model->disconnect(this);
 
     m_completionModels.removeAll(model);
-    endResetModel();
+    if (!willCreateGroups) {
+        endResetModel();
+    }
 
-    if (!m_completionModels.isEmpty()) {
+    if (willCreateGroups) {
         // This performs the reset
         createGroups();
     }
@@ -1875,12 +1597,12 @@ void KateCompletionModel::makeGroupItemsUnique(bool onlyFiltered)
         {
             std::vector<Item> temp;
             temp.reserve(items.size());
-            had.reserve(items.size());
             for (const Item &item : items) {
                 auto it = had.constFind(item.name());
                 if (it != had.constEnd() && *it != item.sourceRow().first && m_needShadowing.contains(item.sourceRow().first)) {
                     continue;
                 }
+
                 had.insert(item.name(), item.sourceRow().first);
                 temp.push_back(item);
             }
@@ -1911,7 +1633,7 @@ void KateCompletionModel::makeGroupItemsUnique(bool onlyFiltered)
 
     QVector<KTextEditor::CodeCompletionModel *> needShadowing;
     for (KTextEditor::CodeCompletionModel *model : std::as_const(m_completionModels)) {
-        KTextEditor::CodeCompletionModelControllerInterface *v4 = dynamic_cast<KTextEditor::CodeCompletionModelControllerInterface *>(model);
+        KTextEditor::CodeCompletionModelControllerInterface *v4 = qobject_cast<KTextEditor::CodeCompletionModelControllerInterface *>(model);
         if (v4 && v4->shouldHideItemsWithEqualNames()) {
             needShadowing.push_back(model);
         }
@@ -2047,7 +1769,7 @@ void KateCompletionModel::updateBestMatches()
     hideOrShowGroup(m_bestMatches);
 }
 
-void KateCompletionModel::rowSelected(const QModelIndex & /*row*/)
+void KateCompletionModel::rowSelected(const QModelIndex & /*row*/) const
 {
     ///@todo delay this
     int rc = widget()->argumentHintModel()->rowCount(QModelIndex());
@@ -2080,3 +1802,5 @@ void KateCompletionModel::clearCompletionModels()
     clearGroups();
     endResetModel();
 }
+
+#include "moc_katecompletionmodel.cpp"
