@@ -1,22 +1,8 @@
-/*  SPDX-License-Identifier: LGPL-2.0-or-later
+/*
+    SPDX-FileCopyrightText: 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
+    SPDX-FileCopyrightText: 2005-2006 Hamish Rodda <rodda@kde.org>
 
-    Copyright (C) 2007-2008 David Nolden <david.nolden.kdevelop@art-master.de>
-    Copyright (C) 2005-2006 Hamish Rodda <rodda@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KTEXTEDITOR_CODECOMPLETIONMODEL_H
@@ -32,6 +18,8 @@ class Document;
 class View;
 
 /**
+ * \class CodeCompletionModel codecompletionmodel.h <KTextEditor/CodeCompletionModel>
+ *
  * \short An item model for providing code completion, and meta information for
  *        enhanced presentation.
  *
@@ -234,14 +222,18 @@ public:
          *  If the mode returns a QVariant of type QString, it will create a small html-widget showing the given html-code,
          *  and embed it into the completion-list under the completion-item.
          *
-         * Warning:
+         * @warning
+         * @code
          *   QWidget* widget;
          *   return QVariant(widget);
+         * @endcode
          * Will not work correctly!
          * Use the following instead.:
+         * @code
          *   QVariant v;
          *   v.setValue<QWidget*>(widget);
          *   return v;
+         * @endcode
          *
          * */
         ExpandingWidget,
@@ -316,7 +308,8 @@ public:
         AccessibilityPrevious,
         /**
          * AccessibilityAccept will be requested on an item if it is expanded, contains an expanding-widget, and the user triggers a special
-         * shortcut to trigger the action associated with the position within the expanding-widget the user has navigated to using AccessibilityNext and AccessibilityPrevious.
+         * shortcut to trigger the action associated with the position within the expanding-widget the user has navigated to using AccessibilityNext and
+         * AccessibilityPrevious.
          *
          * This should return QVariant(true) if an action was triggered, else QVariant(false) or QVariant().
          * */
