@@ -1,25 +1,12 @@
-/* This file is part of the KDE project
-   Copyright (C) 2003-2005 Hamish Rodda <rodda@kde.org>
-   Copyright (C) 2001-2005 Christoph Cullmann <cullmann@kde.org>
-   Copyright (C) 2014 Dominik Haumann <dhaumann@kde.org>
-   Copyright (C) 2002 Christian Couder <christian@kdevelop.org>
-   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
-   Copyright (C) 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
+/*
+    SPDX-FileCopyrightText: 2003-2005 Hamish Rodda <rodda@kde.org>
+    SPDX-FileCopyrightText: 2001-2005 Christoph Cullmann <cullmann@kde.org>
+    SPDX-FileCopyrightText: 2014 Dominik Haumann <dhaumann@kde.org>
+    SPDX-FileCopyrightText: 2002 Christian Couder <christian@kdevelop.org>
+    SPDX-FileCopyrightText: 2001 Joseph Wenninger <jowenn@kde.org>
+    SPDX-FileCopyrightText: 1999 Jochen Wilhelmy <digisnap@cs.tu-berlin.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KTEXTEDITOR_CURSOR_H
@@ -36,6 +23,8 @@ class Document;
 class Range;
 
 /**
+ * \class Cursor cursor.h <KTextEditor/Cursor>
+ *
  * \short The Cursor represents a position in a Document.
  *
  * \section kte_cursor_intro Introduction
@@ -86,8 +75,7 @@ public:
      * The default constructor creates a cursor at position (0, 0).
      */
     Q_DECL_CONSTEXPR Cursor() Q_DECL_NOEXCEPT
-        : m_line(0)
-        , m_column(0) {
+    {
     }
 
     /**
@@ -96,9 +84,8 @@ public:
      * \param line line for cursor
      * \param column column for cursor
      */
-    Q_DECL_CONSTEXPR Cursor(int line, int column) Q_DECL_NOEXCEPT
-        : m_line(line)
-        , m_column(column) {
+    Q_DECL_CONSTEXPR Cursor(int line, int column) Q_DECL_NOEXCEPT : m_line(line), m_column(column)
+    {
     }
 
     /**
@@ -109,7 +96,8 @@ public:
      *       \e text-position, use DocumentCursor::isValidTextPosition(),
      *       or Document::isValidTextPosition().
      */
-    Q_DECL_CONSTEXPR inline bool isValid() const Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR inline bool isValid() const Q_DECL_NOEXCEPT
+    {
         return m_line >= 0 && m_column >= 0;
     }
 
@@ -118,14 +106,16 @@ public:
      * The returned cursor position is set to (-1, -1).
      * \see isValid()
      */
-    Q_DECL_CONSTEXPR static Cursor invalid() Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR static Cursor invalid() Q_DECL_NOEXCEPT
+    {
         return Cursor(-1, -1);
     }
 
     /**
      * Returns a cursor representing the start of any document - i.e., line 0, column 0.
      */
-    Q_DECL_CONSTEXPR static Cursor start() Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR static Cursor start() Q_DECL_NOEXCEPT
+    {
         return Cursor();
     }
 
@@ -133,10 +123,9 @@ public:
      * Returns the cursor position as string in the format "(line, column)".
      * \see fromString()
      */
-    QString toString() const {
-        return QLatin1Char('(') + QString::number(m_line)
-             + QStringLiteral(", ") + QString::number(m_column)
-             + QLatin1Char(')');
+    QString toString() const
+    {
+        return QLatin1Char('(') + QString::number(m_line) + QLatin1String(", ") + QString::number(m_column) + QLatin1Char(')');
     }
 
     /**
@@ -145,7 +134,9 @@ public:
      * is returned.
      * \see toString()
      */
-    static Cursor fromString(const QString& str) Q_DECL_NOEXCEPT {
+    // TODO KF6: Remove this overload in favor of fromString(QStringView).
+    static Cursor fromString(const QString &str) Q_DECL_NOEXCEPT
+    {
         return fromString(str.leftRef(-1));
     }
 
@@ -155,7 +146,16 @@ public:
      * is returned.
      * \see toString()
      */
-    static Cursor fromString(const QStringRef& str) Q_DECL_NOEXCEPT;
+    // TODO KF6: Remove this overload in favor of fromString(QStringView).
+    static Cursor fromString(const QStringRef &str) Q_DECL_NOEXCEPT;
+
+    /**
+     * Returns a Cursor created from the string \p str containing the format
+     * "(line, column)". In case the string cannot be parsed, Cursor::invalid()
+     * is returned.
+     * \see toString()
+     */
+    static Cursor fromString(QStringView str) Q_DECL_NOEXCEPT;
 
     /**
      * \name Position
@@ -168,7 +168,8 @@ public:
      *
      * \param position new cursor position
      */
-    inline void setPosition(const Cursor &position) Q_DECL_NOEXCEPT {
+    inline void setPosition(const Cursor &position) Q_DECL_NOEXCEPT
+    {
         m_line = position.m_line;
         m_column = position.m_column;
     }
@@ -181,7 +182,8 @@ public:
      * \param line new cursor line
      * \param column new cursor column
      */
-    inline void setPosition(int line, int column) Q_DECL_NOEXCEPT {
+    inline void setPosition(int line, int column) Q_DECL_NOEXCEPT
+    {
         m_line = line;
         m_column = column;
     }
@@ -190,7 +192,8 @@ public:
      * Retrieve the line on which this cursor is situated.
      * \return line number, where 0 is the first line.
      */
-    Q_DECL_CONSTEXPR inline int line() const Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR inline int line() const Q_DECL_NOEXCEPT
+    {
         return m_line;
     }
 
@@ -198,7 +201,8 @@ public:
      * Set the cursor line to \e line.
      * \param line new cursor line
      */
-    inline void setLine(int line) Q_DECL_NOEXCEPT {
+    inline void setLine(int line) Q_DECL_NOEXCEPT
+    {
         m_line = line;
     }
 
@@ -206,7 +210,8 @@ public:
      * Retrieve the column on which this cursor is situated.
      * \return column number, where 0 is the first column.
      */
-    Q_DECL_CONSTEXPR inline int column() const Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR inline int column() const Q_DECL_NOEXCEPT
+    {
         return m_column;
     }
 
@@ -214,7 +219,8 @@ public:
      * Set the cursor column to \e column.
      * \param column new cursor column
      */
-    inline void setColumn(int column) Q_DECL_NOEXCEPT {
+    inline void setColumn(int column) Q_DECL_NOEXCEPT
+    {
         m_column = column;
     }
 
@@ -222,7 +228,8 @@ public:
      * Determine if this cursor is located at the start of a line (= at column 0).
      * \return \e true if the cursor is situated at the start of the line, \e false if it isn't.
      */
-    Q_DECL_CONSTEXPR inline bool atStartOfLine() const Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR inline bool atStartOfLine() const Q_DECL_NOEXCEPT
+    {
         return m_column == 0;
     }
 
@@ -230,7 +237,8 @@ public:
      * Determine if this cursor is located at the start of a document (= at position (0, 0)).
      * \return \e true if the cursor is situated at the start of the document, \e false if it isn't.
      */
-    Q_DECL_CONSTEXPR inline bool atStartOfDocument() const Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR inline bool atStartOfDocument() const Q_DECL_NOEXCEPT
+    {
         return m_line == 0 && m_column == 0;
     }
 
@@ -239,7 +247,8 @@ public:
      * \param line will be filled with current cursor line
      * \param column will be filled with current cursor column
      */
-    inline void position(int &line, int &column) const Q_DECL_NOEXCEPT {
+    inline void position(int &line, int &column) const Q_DECL_NOEXCEPT
+    {
         line = m_line;
         column = m_column;
     }
@@ -251,7 +260,8 @@ public:
      * \param c2 the second position
      * \return a the summation of the two input cursors
      */
-    Q_DECL_CONSTEXPR inline friend Cursor operator+(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR inline friend Cursor operator+(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT
+    {
         return Cursor(c1.line() + c2.line(), c1.column() + c2.column());
     }
 
@@ -261,7 +271,8 @@ public:
      * \param c2 the position to add
      * \return a reference to the cursor which has just been added to
      */
-    inline friend Cursor &operator+=(Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT {
+    inline friend Cursor &operator+=(Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT
+    {
         c1.setPosition(c1.line() + c2.line(), c1.column() + c2.column());
         return c1;
     }
@@ -274,7 +285,8 @@ public:
      * \param c2 the second position
      * \return a cursor representing the subtraction of \p c2 from \p c1
      */
-    Q_DECL_CONSTEXPR inline friend Cursor operator-(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR inline friend Cursor operator-(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT
+    {
         return Cursor(c1.line() - c2.line(), c1.column() - c2.column());
     }
 
@@ -284,7 +296,8 @@ public:
      * \param c2 the position to subtract
      * \return a reference to the cursor which has just been subtracted from
      */
-    inline friend Cursor &operator-=(Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT {
+    inline friend Cursor &operator-=(Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT
+    {
         c1.setPosition(c1.line() - c2.line(), c1.column() - c2.column());
         return c1;
     }
@@ -299,7 +312,8 @@ public:
      * \param c2 second cursor to compare
      * \return \e true, if c1's and c2's line and column are \e equal.
      */
-    Q_DECL_CONSTEXPR inline friend bool operator==(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR inline friend bool operator==(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT
+    {
         return c1.line() == c2.line() && c1.column() == c2.column();
     }
 
@@ -309,7 +323,8 @@ public:
      * \param c2 second cursor to compare
      * \return \e true, if c1's and c2's line and column are \e not equal.
      */
-    Q_DECL_CONSTEXPR inline friend bool operator!=(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR inline friend bool operator!=(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT
+    {
         return !(c1 == c2);
     }
 
@@ -320,7 +335,8 @@ public:
      * \return \e true, if c1's position is greater than c2's position,
      *         otherwise \e false.
      */
-    Q_DECL_CONSTEXPR inline friend bool operator>(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR inline friend bool operator>(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT
+    {
         return c1.line() > c2.line() || (c1.line() == c2.line() && c1.m_column > c2.m_column);
     }
 
@@ -331,7 +347,8 @@ public:
      * \return \e true, if c1's position is greater than or equal to c2's
      *         position, otherwise \e false.
      */
-    Q_DECL_CONSTEXPR inline friend bool operator>=(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT{
+    Q_DECL_CONSTEXPR inline friend bool operator>=(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT
+    {
         return c1.line() > c2.line() || (c1.line() == c2.line() && c1.m_column >= c2.m_column);
     }
 
@@ -342,7 +359,8 @@ public:
      * \return \e true, if c1's position is greater than or equal to c2's
      *         position, otherwise \e false.
      */
-    Q_DECL_CONSTEXPR inline friend bool operator<(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR inline friend bool operator<(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT
+    {
         return !(c1 >= c2);
     }
 
@@ -353,14 +371,16 @@ public:
      * \return \e true, if c1's position is lesser than or equal to c2's
      *         position, otherwise \e false.
      */
-    Q_DECL_CONSTEXPR inline friend bool operator<=(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT {
+    Q_DECL_CONSTEXPR inline friend bool operator<=(const Cursor &c1, const Cursor &c2) Q_DECL_NOEXCEPT
+    {
         return !(c1 > c2);
     }
 
     /**
      * qDebug() stream operator.  Writes this cursor to the debug output in a nicely formatted way.
      */
-    inline friend QDebug operator<< (QDebug s, const Cursor &cursor) {
+    inline friend QDebug operator<<(QDebug s, const Cursor &cursor)
+    {
         s.nospace() << "(" << cursor.line() << ", " << cursor.column() << ")";
         return s.space();
     }
@@ -371,14 +391,14 @@ private:
      *
      * Cursor line
      */
-    int m_line;
+    int m_line = 0;
 
     /**
      * \internal
      *
      * Cursor column
      */
-    int m_column;
+    int m_column = 0;
 };
 
 } // namespace KTextEditor
@@ -390,22 +410,22 @@ Q_DECLARE_METATYPE(KTextEditor::Cursor)
  * QHash function for KTextEditor::Cursor.
  * Returns the hash value for @p cursor.
  */
-inline uint qHash(const KTextEditor::Cursor& cursor, uint seed = 0) Q_DECL_NOTHROW
+inline uint qHash(const KTextEditor::Cursor &cursor, uint seed = 0) Q_DECL_NOTHROW
 {
     return qHash(qMakePair(cursor.line(), cursor.column()), seed);
 }
 
 namespace QTest
 {
-    // forward declaration of template in qtestcase.h
-    template<typename T> char* toString(const T&);
+// forward declaration of template in qtestcase.h
+template<typename T>
+char *toString(const T &);
 
-    /**
-     * QTestLib integration to have nice output in e.g. QCOMPARE failures.
-     */
-    template<>
-    KTEXTEDITOR_EXPORT char *toString(const KTextEditor::Cursor &cursor);
+/**
+ * QTestLib integration to have nice output in e.g. QCOMPARE failures.
+ */
+template<>
+KTEXTEDITOR_EXPORT char *toString(const KTextEditor::Cursor &cursor);
 }
 
 #endif
-
