@@ -6,7 +6,7 @@
 
 // BEGIN Includes
 #include "katemodemanager.h"
-#include "katewildcardmatcher.h"
+#include "katemodemenulist.h"
 #include "katestatusbar.h"
 
 #include "kateconfig.h"
@@ -17,8 +17,13 @@
 #include "kateview.h"
 
 #include <KConfigGroup>
+#include <KSyntaxHighlighting/WildcardMatcher>
 
+#include <QFileInfo>
 #include <QMimeDatabase>
+
+#include <algorithm>
+#include <limits>
 // END Includes
 
 static QStringList vectorToList(const QVector<QString> &v)
@@ -65,7 +70,6 @@ void KateModeManager::update()
         KConfigGroup cg(&config, g[z]);
 
         KateFileType *type = new KateFileType();
-        type->number = z;
         type->name = g[z];
         type->wildcards = cg.readXdgListEntry(QStringLiteral("Wildcards"));
         type->mimetypes = cg.readXdgListEntry(QStringLiteral("Mimetypes"));
@@ -86,6 +90,11 @@ void KateModeManager::update()
         } else {
             type->section = cg.readEntry(QStringLiteral("Section"));
             type->version = cg.readEntry(QStringLiteral("Highlighting Version"));
+
+            // already add all non-highlighting generated user types
+            if (!type->hlGenerated) {
+                m_types.append(type);
+            }
         }
 
         // insert into the hash...
@@ -110,15 +119,20 @@ void KateModeManager::update()
         bool newType = false;
         if (m_name2Type.contains(modes[i].name())) {
             type = m_name2Type[modes[i].name()];
+
+            // add if hl generated, we skipped that stuff above
+            if (type->hlGenerated) {
+                m_types.append(type);
+            }
         } else {
             newType = true;
             type = new KateFileType();
             type->name = modes[i].name();
             type->priority = 0;
+            type->hlGenerated = true;
+            m_types.append(type);
             m_name2Type.insert(type->name, type);
         }
-        // only the types that exist or are valid are added
-        m_types.append(type);
 
         if (newType || type->version != QString::number(modes[i].version())) {
             type->name = modes[i].name();
@@ -129,7 +143,6 @@ void KateModeManager::update()
             type->version = QString::number(modes[i].version());
             type->indenter = modes[i].indenter();
             type->hl = modes[i].name();
-            type->hlGenerated = true;
         }
 
         type->translatedName = modes[i].translatedName();
@@ -154,7 +167,8 @@ void KateModeManager::update()
 
     // update the mode menu of the status bar, for all views.
     // this menu uses the KateFileType objects
-    for (auto *view : KTextEditor::EditorPrivate::self()->views()) {
+    const auto views = KTextEditor::EditorPrivate::self()->views();
+    for (auto *view : views) {
         if (view->statusBar() && view->statusBar()->modeMenu()) {
             view->statusBar()->modeMenu()->reloadItems();
         }
@@ -259,58 +273,45 @@ QString KateModeManager::fileType(KTextEditor::DocumentPrivate *doc, const QStri
     } else {
         mtName = doc->mimeType();
     }
-
-    QList<KateFileType *> types;
-    for (KateFileType *type : qAsConst(m_types)) {
-        if (type->mimetypes.indexOf(mtName) > -1) {
-            types.append(type);
-        }
-    }
-
-    if (!types.isEmpty()) {
-        int pri = -1;
-        QString name;
-
-        for (KateFileType *type : qAsConst(types)) {
-            if (type->priority > pri) {
-                pri = type->priority;
-                name = type->name;
-            }
-        }
-
-        return name;
-    }
-
-    return QString();
+    return mimeTypesFind(mtName);
 }
 
-QString KateModeManager::wildcardsFind(const QString &fileName)
+template<typename UnaryStringPredicate>
+static QString findHighestPriorityTypeNameIf(const QList<KateFileType *> &types, QStringList KateFileType::*list, UnaryStringPredicate anyOfCondition)
 {
-    KateFileType *match = nullptr;
-    int minPrio = -1;
-    for (KateFileType *type : qAsConst(m_types)) {
-        if (type->priority <= minPrio) {
-            continue;
-        }
-
-        for (const QString &wildcard : qAsConst(type->wildcards)) {
-            if (KateWildcardMatcher::exactMatch(fileName, wildcard)) {
-                match = type;
-                minPrio = type->priority;
-                break;
-            }
+    const KateFileType *match = nullptr;
+    auto matchPriority = std::numeric_limits<int>::lowest();
+    for (const KateFileType *type : types) {
+        if (type->priority > matchPriority && std::any_of((type->*list).cbegin(), (type->*list).cend(), anyOfCondition)) {
+            match = type;
+            matchPriority = type->priority;
         }
     }
+    return match == nullptr ? QString() : match->name;
+}
 
-    return (match == nullptr) ? QString() : match->name;
+QString KateModeManager::wildcardsFind(const QString &fileName) const
+{
+    const auto fileNameNoPath = QFileInfo{fileName}.fileName();
+    return findHighestPriorityTypeNameIf(m_types, &KateFileType::wildcards, [&fileNameNoPath](const QString &wildcard) {
+        return KSyntaxHighlighting::WildcardMatcher::exactMatch(fileNameNoPath, wildcard);
+    });
+}
+
+QString KateModeManager::mimeTypesFind(const QString &mimeTypeName) const
+{
+    return findHighestPriorityTypeNameIf(m_types, &KateFileType::mimetypes, [&mimeTypeName](const QString &name) {
+        return mimeTypeName == name;
+    });
 }
 
 const KateFileType &KateModeManager::fileType(const QString &name) const
 {
-    for (int i = 0; i < m_types.size(); ++i)
+    for (int i = 0; i < m_types.size(); ++i) {
         if (m_types[i]->name == name) {
             return *m_types[i];
         }
+    }
 
     static KateFileType notype;
     return notype;
