@@ -47,8 +47,16 @@ inline static bool overlapScrollBar()
 }
 }
 
-void KateModeMenuList::init(const SearchBarPosition searchBarPos)
+void KateModeMenuList::init()
 {
+    connect(this, &QMenu::aboutToShow, this, &KateModeMenuList::onAboutToShowMenu);
+}
+
+void KateModeMenuList::onAboutToShowMenu()
+{
+    if (m_initialized) {
+        return;
+    }
     /*
      * Fix font size & font style: display the font correctly when changing it from the
      * KDE Plasma preferences. For example, the font type "Menu" is displayed, but "font()"
@@ -164,13 +172,8 @@ void KateModeMenuList::init(const SearchBarPosition searchBarPos)
     }
 
     layoutSearchBar->addWidget(m_searchBar);
-    if (searchBarPos == Top) {
-        layoutContainer->addLayout(layoutSearchBar);
-    }
     layoutContainer->addLayout(m_layoutList);
-    if (searchBarPos == Bottom) {
-        layoutContainer->addLayout(layoutSearchBar);
-    }
+    layoutContainer->addLayout(layoutSearchBar);
 
     QWidgetAction *widAct = new QWidgetAction(this);
     widAct->setDefaultWidget(container);
@@ -181,10 +184,17 @@ void KateModeMenuList::init(const SearchBarPosition searchBarPos)
      * This also applies to double-clicks.
      */
     connect(m_list, &KateModeMenuListData::ListView::clicked, this, &KateModeMenuList::selectHighlighting);
+
+    m_initialized = true;
 }
 
 void KateModeMenuList::reloadItems()
 {
+    // We aren't initialized, nothing to reload
+    if (!m_initialized) {
+        return;
+    }
+
     const QString searchText = m_searchBar->text().trimmed();
     m_searchBar->m_bestResults.clear();
     if (!isHidden()) {
@@ -725,13 +735,13 @@ bool KateModeMenuListData::ListItem::matchExtension(const QString &text) const
     for (const auto &ext : m_type->wildcards) {
         // File extension
         if (ext.startsWith(QLatin1String("*."))) {
-            if (text.length() == ext.length() - 2 && text.compare(ext.midRef(2), Qt::CaseInsensitive) == 0) {
+            if (text.length() == ext.length() - 2 && text.compare(QStringView(ext).mid(2), Qt::CaseInsensitive) == 0) {
                 return true;
             }
         } else if (text.length() != ext.length() || ext.endsWith(QLatin1Char('*'))) {
             continue;
             // Full name
-        } else if (text.compare(&ext, Qt::CaseInsensitive) == 0) {
+        } else if (text.compare(ext, Qt::CaseInsensitive) == 0) {
             return true;
         }
     }
@@ -983,8 +993,8 @@ void KateModeMenuListData::SearchLine::updateSearch(const QString &s)
          * be displayed, as it isn't necessary.
          */
         if (!bNotShowBestResults
-            && (item->getSearchName().compare(&searchText, m_caseSensitivity) == 0
-                || (bExactMatch && item->getMode()->nameTranslated().compare(&searchText, m_caseSensitivity) == 0))) {
+            && (item->getSearchName().compare(searchText, m_caseSensitivity) == 0
+                || (bExactMatch && item->getMode()->nameTranslated().compare(searchText, m_caseSensitivity) == 0))) {
             if (lastItem == -1) {
                 bNotShowBestResults = true;
             } else {
@@ -1108,7 +1118,7 @@ void KateModeMenuListData::SearchLine::updateSearch(const QString &s)
 
         // Special Case: always show the "R Script" mode first by typing "r" in the search box
         if (searchText.length() == 1 && searchText.compare(QLatin1String("r"), m_caseSensitivity) == 0) {
-            for (const QPair<ListItem *, int> &itemBestResults : qAsConst(m_bestResults)) {
+            for (const QPair<ListItem *, int> &itemBestResults : std::as_const(m_bestResults)) {
                 listModel->takeRow(itemBestResults.second);
                 ++rowModelBestResults;
                 if (itemBestResults.first->getMode()->name == QLatin1String("R Script")) {
@@ -1121,7 +1131,7 @@ void KateModeMenuListData::SearchLine::updateSearch(const QString &s)
             }
         } else {
             // Move items to the "Best Search Matches" section
-            for (const QPair<ListItem *, int> &itemBestResults : qAsConst(m_bestResults)) {
+            for (const QPair<ListItem *, int> &itemBestResults : std::as_const(m_bestResults)) {
                 listModel->takeRow(itemBestResults.second);
                 listModel->insertRow(++rowModelBestResults, itemBestResults.first);
                 listView->setRowHidden(rowModelBestResults, false);
@@ -1194,3 +1204,5 @@ void KateModeMenuList::updateMenu(KTextEditor::Document *doc)
 {
     m_doc = static_cast<KTextEditor::DocumentPrivate *>(doc);
 }
+
+#include "moc_katemodemenulist.cpp"
