@@ -6,23 +6,11 @@ var katescript = {
     "kate-version": "5.1"
 }; // kate-script-header, must be at the start of the file without comments, pure json
 
-/**
- * This file is part of the Kate Project.
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License version 2 as published by the Free Software Foundation.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- */
+/*
+    This file is part of the Kate Project.
+
+    SPDX-License-Identifier: LGPL-2.0-only
+*/
 // loosely based on the vim ada indent file
 //-------- extract from original vim header follows --------------
 //
@@ -49,8 +37,6 @@ var katescript = {
 // TODO: 'protected', 'task', 'select' &
 //       possibly other keywords not recognised
 
-"use strict";
-
 // required katepart js libraries
 require ("range.js");
 require ("cursor.js");
@@ -64,11 +50,11 @@ var debugMode = false;
 
 //END USER CONFIGURATION
 
-const AdaComment    = /\s*--.*$/;
-const unfStmt       = /([.=\(]|:=[^;]*)\s*$/;
-const unfLoop       = /^\s*(for|while)\b(?!.*\bloop\b)/i;
-const AdaBlockStart = /^\s*(if\b|while\b|else\b|elsif\b|loop\b|for\b.*\b(loop|use)\b|declare\b|begin\b|type\b.*\bis\b[^;]*$|(type\b.*)?\brecord\b|procedure\b|function\b|with\s+function\b|accept\b|do\b|task\b|generic\b|package\b|private\b|then\b|when\b|is\b)/i;
-const StatementStart = /^\s*(if|when|while|else|elsif|loop|for\b.*\b(loop|use)|begin)\b/i;
+var AdaComment    = /\s*--.*$/;
+var unfStmt       = /([.=\(]|:=[^;]*)\s*$/;
+var unfLoop       = /^\s*(for|while)\b(?!.*\bloop\b)/i;
+var AdaBlockStart = /^\s*(if\b|while\b|else\b|elsif\b|loop\b|for\b.*\b(loop|use)\b|declare\b|begin\b|type\b.*\bis\b[^;]*$|(type\b.*)?\brecord\b|procedure\b|function\b|with\s+function\b|accept\b|do\b|task\b|generic\b|package\b|private\b|then\b|when\b|is\b)/i;
+var StatementStart = /^\s*(if|when|while|else|elsif|loop|for\b.*\b(loop|use)|begin)\b/i;
 
 function dbg() {
     if (debugMode) {
@@ -85,7 +71,7 @@ function dbg() {
 
 
 // regexp of keywords & patterns that cause reindenting of the current line.
-const AdaReIndent = /^\s*((then|end|elsif|when|exception|begin|is|record|private)\s+|<<\w+>>|end;|[#\)])(.*)$/;
+var AdaReIndent = /^\s*((then|end|elsif|when|exception|begin|is|record|private)\s+|<<\w+>>|end;|[#\)])(.*)$/;
 
 // characters which trigger indent, beside the default '\n'
 var triggerCharacters = " \t)#>;";
