@@ -74,6 +74,7 @@ void KateBookmarks::createActions(KActionCollection *ac)
 
     KActionMenu *actionMenu = new KActionMenu(i18n("&Bookmarks"), this);
     actionMenu->setPopupMode(QToolButton::InstantPopup);
+    actionMenu->setIcon(QIcon::fromTheme(QStringLiteral("bookmarks")));
     ac->addAction(QStringLiteral("bookmarks"), actionMenu);
     m_bookmarksMenu = actionMenu->menu();
 
@@ -273,3 +274,5 @@ void KateBookmarks::marksChanged()
         m_bookmarkClear->setEnabled(!m_view->doc()->marks().isEmpty());
     }
 }
+
+#include "moc_katebookmarks.cpp"
