@@ -8,24 +8,22 @@
 #ifndef KATE_GLOBAL_H
 #define KATE_GLOBAL_H
 
-#include "katescript.h"
-#include "variable.h"
 #include <ktexteditor_export.h>
 
-#include "ktexteditor/view.h"
 #include <ktexteditor/editor.h>
+#include <ktexteditor/view.h>
 
 #include <KAboutData>
 #include <KSharedConfig>
 
 #include <KTextEditor/Application>
-#include <KTextEditor/Command>
 #include <KTextEditor/MainWindow>
 
 #include <QList>
-#include <QMap>
 #include <QPointer>
-#include <QScopedPointer>
+
+#include <array>
+#include <memory>
 
 class QStringListModel;
 
@@ -42,6 +40,7 @@ class DocumentPrivate;
 namespace KTextEditor
 {
 class ViewPrivate;
+class Command;
 }
 class KateScriptManager;
 class KDirWatch;
@@ -89,13 +88,14 @@ private:
      * Default constructor, private, as singleton
      * @param staticInstance pointer to fill with content of this
      */
+    KTEXTEDITOR_NO_EXPORT
     explicit EditorPrivate(QPointer<KTextEditor::EditorPrivate> &staticInstance);
 
 public:
     /**
      * Destructor
      */
-    ~EditorPrivate();
+    ~EditorPrivate() override;
 
     /**
      * Create a new document object
@@ -345,14 +345,36 @@ public:
     /**
      * Copy text to clipboard an remember it in the history
      * @param text text to copy to clipboard, does nothing if empty!
+     * @param fileName fileName of the text to copy, used for highlighting
      */
-    void copyToClipboard(const QString &text);
+    void copyToClipboard(const QString &text, const QString &fileName);
+
+    /**
+     * A clipboard entry stores the copied text and the filename of
+     * the copied text.
+     */
+    struct ClipboardEntry {
+        /**
+         * The copied text
+         */
+        QString text;
+        /**
+         * The file name of the file containing the copied text,
+         * used for syntax highlighting
+         */
+        QString fileName;
+    };
+
+    friend inline bool operator==(const ClipboardEntry &lhs, const ClipboardEntry &rhs)
+    {
+        return lhs.text == rhs.text && lhs.fileName == rhs.fileName;
+    }
 
     /**
      * Clipboard history, filled with text we ever copied
      * to clipboard via copyToClipboard.
      */
-    const QStringList &clipboardHistory() const
+    const QVector<ClipboardEntry> &clipboardHistory() const
     {
         return m_clipboardHistory;
     }
@@ -378,7 +400,10 @@ public:
     /**
      * @return list of available input mode factories
      */
-    QList<KateAbstractInputModeFactory *> inputModeFactories();
+    const std::array<std::unique_ptr<KateAbstractInputModeFactory>, KTextEditor::View::ViInputMode + 1> &inputModeFactories()
+    {
+        return m_inputModeFactories;
+    }
 
     /**
      * Search pattern history shared among simple/power search instances.
@@ -405,6 +430,10 @@ public:
      */
     void triggerConfigChanged();
 
+    void copyToMulticursorClipboard(const QStringList &texts);
+
+    QStringList multicursorClipboard() const;
+
 private Q_SLOTS:
     /**
      * Emit configChanged if needed.
@@ -513,7 +542,7 @@ private:
     /**
      * clipboard history
      */
-    QStringList m_clipboardHistory;
+    QVector<ClipboardEntry> m_clipboardHistory;
 
     /**
      * Dummy application object to be null safe
@@ -531,9 +560,18 @@ private:
     KTextEditor::MainWindow m_dummyMainWindow;
 
     /**
-     * input modes map
+     * input modes factories
+     * for all input modes in the KTextEditor::View::InputMode we have here an entry
      */
-    QMap<KTextEditor::View::InputMode, KateAbstractInputModeFactory *> m_inputModeFactories;
+    std::array<std::unique_ptr<KateAbstractInputModeFactory>, KTextEditor::View::ViInputMode + 1> m_inputModeFactories;
+
+    /**
+     * simple list that stores text copied
+     * from all cursors selection
+     * It's main purpose is providing multi-paste
+     * support.
+     */
+    QStringList m_multicursorClipboard;
 
     /**
      * Shared history models for search & replace.
