@@ -44,12 +44,12 @@ KateTemplateHandler::KateTemplateHandler(KTextEditor::ViewPrivate *view,
     m_templateScript.setView(m_view);
 
     // remember selection, it will be lost when inserting the template
-    QScopedPointer<MovingRange> selection(doc()->newMovingRange(m_view->selectionRange(), MovingRange::DoNotExpand));
+    std::unique_ptr<MovingRange> selection(doc()->newMovingRange(m_view->selectionRange(), MovingRange::DoNotExpand));
 
     m_undoManager->setAllowComplexMerge(true);
 
     {
-        connect(doc(), &KTextEditor::DocumentPrivate::textInserted, this, &KateTemplateHandler::slotTemplateInserted);
+        connect(doc(), &KTextEditor::DocumentPrivate::textInsertedRange, this, &KateTemplateHandler::slotTemplateInserted);
         KTextEditor::Document::EditingTransaction t(doc());
         // insert the raw template string
         if (!doc()->insertText(position, templateString)) {
@@ -81,7 +81,7 @@ KateTemplateHandler::KateTemplateHandler(KTextEditor::ViewPrivate *view,
         jump(1, true);
 
         connect(doc(), &KTextEditor::Document::viewCreated, this, &KateTemplateHandler::slotViewCreated);
-        connect(doc(), &KTextEditor::DocumentPrivate::textInserted, this, &KateTemplateHandler::updateDependentFields);
+        connect(doc(), &KTextEditor::DocumentPrivate::textInsertedRange, this, &KateTemplateHandler::updateDependentFields);
         connect(doc(), &KTextEditor::DocumentPrivate::textRemoved, this, &KateTemplateHandler::updateDependentFields);
         connect(doc(), &KTextEditor::Document::aboutToReload, this, &KateTemplateHandler::deleteLater);
 
@@ -170,7 +170,7 @@ void KateTemplateHandler::jump(int by, bool initial)
 
 void KateTemplateHandler::jumpToFinalCursorPosition()
 {
-    for (const auto &field : qAsConst(m_fields)) {
+    for (const auto &field : std::as_const(m_fields)) {
         if (field.kind == TemplateField::FinalCursorPosition) {
             view()->setCursorPosition(field.range->toRange().start());
             return;
@@ -179,11 +179,11 @@ void KateTemplateHandler::jumpToFinalCursorPosition()
     view()->setCursorPosition(m_wholeTemplateRange->end());
 }
 
-void KateTemplateHandler::slotTemplateInserted(Document * /*document*/, const Range &range)
+void KateTemplateHandler::slotTemplateInserted(Document * /*document*/, Range range)
 {
     m_wholeTemplateRange.reset(doc()->newMovingRange(range, MovingRange::ExpandLeft | MovingRange::ExpandRight));
 
-    disconnect(doc(), &KTextEditor::DocumentPrivate::textInserted, this, &KateTemplateHandler::slotTemplateInserted);
+    disconnect(doc(), &KTextEditor::DocumentPrivate::textInsertedRange, this, &KateTemplateHandler::slotTemplateInserted);
 }
 
 KTextEditor::DocumentPrivate *KateTemplateHandler::doc() const
@@ -266,7 +266,7 @@ void KateTemplateHandler::parseFields(const QString &templateText)
     // compute start cursor of a match
     auto startOfMatch = [this, &templateText](const QRegularExpressionMatch &match) {
         const auto offset = match.capturedStart(0);
-        const auto left = templateText.leftRef(offset);
+        const auto left = QStringView(templateText).left(offset);
         const auto nl = QLatin1Char('\n');
         const auto rel_lineno = left.count(nl);
         const auto start = m_wholeTemplateRange->start().toCursor();
@@ -293,7 +293,7 @@ void KateTemplateHandler::parseFields(const QString &templateText)
         }
         // a template field was found, instantiate a field object and populate it
         auto defaultMatch = defaultField.match(match.captured(0));
-        auto contents = match.captured(1);
+        const QString contents = match.captured(1);
         TemplateField f;
         f.range.reset(createMovingRangeForMatch(match));
         f.identifier = contents;
@@ -301,7 +301,7 @@ void KateTemplateHandler::parseFields(const QString &templateText)
         if (defaultMatch.hasMatch()) {
             // the field has a default value, i.e. ${foo=3}
             f.defaultValue = defaultMatch.captured(1);
-            f.identifier = contents.leftRef(contents.indexOf(QLatin1Char('='))).trimmed().toString();
+            f.identifier = QStringView(contents).left(contents.indexOf(QLatin1Char('='))).trimmed().toString();
         } else if (f.identifier.contains(QLatin1Char('('))) {
             // field is a function call when it contains an opening parenthesis
             f.kind = TemplateField::FunctionCall;
@@ -309,7 +309,7 @@ void KateTemplateHandler::parseFields(const QString &templateText)
             // field marks the final cursor position
             f.kind = TemplateField::FinalCursorPosition;
         }
-        for (const auto &other : qAsConst(m_fields)) {
+        for (const auto &other : std::as_const(m_fields)) {
             if (other.kind == TemplateField::Editable && !(f == other) && other.identifier == f.identifier) {
                 // field is a mirror field
                 f.kind = TemplateField::Mirror;
@@ -336,14 +336,14 @@ void KateTemplateHandler::setupFieldRanges()
     m_wholeTemplateRange->setAttribute(getAttribute(config->templateBackgroundColor(), 200));
 
     // color all the template fields
-    for (const auto &field : qAsConst(m_fields)) {
+    for (const auto &field : std::as_const(m_fields)) {
         field.range->setAttribute(field.kind == TemplateField::Editable ? editableAttribute : notEditableAttribute);
     }
 }
 
 void KateTemplateHandler::setupDefaultValues()
 {
-    for (const auto &field : qAsConst(m_fields)) {
+    for (const auto &field : std::as_const(m_fields)) {
         if (field.kind != TemplateField::Editable) {
             continue;
         }
@@ -375,7 +375,7 @@ void KateTemplateHandler::initializeTemplate()
     }
 }
 
-const KateTemplateHandler::TemplateField KateTemplateHandler::fieldForRange(const KTextEditor::Range &range) const
+const KateTemplateHandler::TemplateField KateTemplateHandler::fieldForRange(KTextEditor::Range range) const
 {
     for (const auto &field : m_fields) {
         if (field.range->contains(range.start()) || field.range->end() == range.start()) {
@@ -388,7 +388,7 @@ const KateTemplateHandler::TemplateField KateTemplateHandler::fieldForRange(cons
     return {};
 }
 
-void KateTemplateHandler::updateDependentFields(Document *document, const Range &range)
+void KateTemplateHandler::updateDependentFields(Document *document, Range range)
 {
     Q_ASSERT(document == doc());
     Q_UNUSED(document);
@@ -434,7 +434,7 @@ void KateTemplateHandler::updateDependentFields(Document *document, const Range
     // turn off expanding left/right for all ranges except @p current;
     // this prevents ranges from overlapping each other when they are adjacent
     auto dontExpandOthers = [this](const TemplateField &current) {
-        for (int i = 0; i < m_fields.size(); i++) {
+        for (qsizetype i = 0; i < m_fields.size(); i++) {
             if (current.range != m_fields.at(i).range) {
                 m_fields.at(i).range->setInsertBehaviors(MovingRange::DoNotExpand);
             } else {
@@ -516,3 +516,5 @@ KTextEditor::ViewPrivate *KateTemplateHandler::view() const
 {
     return m_view;
 }
+
+#include "moc_katetemplatehandler.cpp"
