@@ -25,11 +25,11 @@ KateAnimation::KateAnimation(KMessageWidget *widget, EffectType effect)
     if (effect == FadeEffect) {
         m_fadeEffect = new KateFadeEffect(widget);
 
-        connect(m_fadeEffect, SIGNAL(hideAnimationFinished()), this, SIGNAL(widgetHidden()));
-        connect(m_fadeEffect, SIGNAL(showAnimationFinished()), this, SIGNAL(widgetShown()));
+        connect(m_fadeEffect, &KateFadeEffect::hideAnimationFinished, this, &KateAnimation::widgetHidden);
+        connect(m_fadeEffect, &KateFadeEffect::showAnimationFinished, this, &KateAnimation::widgetShown);
     } else {
-        connect(m_widget, SIGNAL(hideAnimationFinished()), this, SIGNAL(widgetHidden()));
-        connect(m_widget, SIGNAL(showAnimationFinished()), this, SIGNAL(widgetShown()));
+        connect(m_widget.data(), &KMessageWidget::hideAnimationFinished, this, &KateAnimation::widgetHidden);
+        connect(m_widget.data(), &KMessageWidget::showAnimationFinished, this, &KateAnimation::widgetShown);
     }
 }
 
@@ -58,7 +58,7 @@ void KateAnimation::show()
         }
     } else {
         m_widget->show();
-        emit widgetShown();
+        Q_EMIT widgetShown();
     }
 }
 
@@ -67,7 +67,8 @@ void KateAnimation::hide()
     Q_ASSERT(m_widget != nullptr);
 
     // hide according to effects config
-    if (m_widget->style()->styleHint(QStyle::SH_Widget_Animate, nullptr, m_widget) || KTextEditor::EditorPrivate::unitTestMode() // due to timing issues in the unit test
+    if (m_widget->style()->styleHint(QStyle::SH_Widget_Animate, nullptr, m_widget)
+        || KTextEditor::EditorPrivate::unitTestMode() // due to timing issues in the unit test
     ) {
         // hide depending on effect
         if (m_fadeEffect) {
@@ -77,6 +78,8 @@ void KateAnimation::hide()
         }
     } else {
         m_widget->hide();
-        emit widgetHidden();
+        Q_EMIT widgetHidden();
     }
 }
+
+#include "moc_kateanimation.cpp"
