@@ -20,18 +20,20 @@ class KateAnnotationItemDelegate : public KTextEditor::AbstractAnnotationItemDel
     Q_OBJECT
 
 public:
-    explicit KateAnnotationItemDelegate(KateViewInternal *internalView, QObject *parent);
+    explicit KateAnnotationItemDelegate(QObject *parent);
     ~KateAnnotationItemDelegate() override;
 
 public:
     void paint(QPainter *painter, const KTextEditor::StyleOptionAnnotationItem &option, KTextEditor::AnnotationModel *model, int line) const override;
-    bool helpEvent(QHelpEvent *event, KTextEditor::View *view, const KTextEditor::StyleOptionAnnotationItem &option, KTextEditor::AnnotationModel *model, int line) override;
+    bool helpEvent(QHelpEvent *event,
+                   KTextEditor::View *view,
+                   const KTextEditor::StyleOptionAnnotationItem &option,
+                   KTextEditor::AnnotationModel *model,
+                   int line) override;
     void hideTooltip(KTextEditor::View *view) override;
     QSize sizeHint(const KTextEditor::StyleOptionAnnotationItem &option, KTextEditor::AnnotationModel *model, int line) const override;
 
 private:
-    KateViewInternal *m_internalView;
-    KTextEditor::ViewPrivate *m_view;
 
     mutable qreal m_maxCharWidth = 0.0;
     mutable QFontMetricsF m_cachedDataContentFontMetrics;
