@@ -53,7 +53,7 @@ CommandMode::CommandMode(EmulatedCommandBar *emulatedCommandBar,
         cmds.push_back(cmd);
     }
 
-    for (KTextEditor::Command *cmd : qAsConst(cmds)) {
+    for (KTextEditor::Command *cmd : std::as_const(cmds)) {
         QStringList l = cmd->cmds();
 
         for (int z = 0; z < l.count(); z++) {
@@ -66,7 +66,7 @@ CommandMode::CommandMode(EmulatedCommandBar *emulatedCommandBar,
 
 bool CommandMode::handleKeyPress(const QKeyEvent *keyEvent)
 {
-    if (keyEvent->modifiers() == Qt::ControlModifier && (keyEvent->key() == Qt::Key_D || keyEvent->key() == Qt::Key_F)) {
+    if (keyEvent->modifiers() == CONTROL_MODIFIER && (keyEvent->key() == Qt::Key_D || keyEvent->key() == Qt::Key_F)) {
         CommandMode::ParsedSedExpression parsedSedExpression = parseAsSedExpression();
         if (parsedSedExpression.parsedSuccessfully) {
             const bool clearFindTerm = (keyEvent->key() == Qt::Key_D);
@@ -87,8 +87,9 @@ bool CommandMode::handleKeyPress(const QKeyEvent *keyEvent)
 void CommandMode::editTextChanged(const QString &newText)
 {
     Q_UNUSED(newText); // We read the current text from m_edit.
-    if (m_completer->isCompletionActive())
+    if (m_completer->isCompletionActive()) {
         return;
+    }
     // Command completion doesn't need to be manually invoked.
     if (!withoutRangeExpression().isEmpty() && !m_completer->isNextTextChangeDueToCompletionChange()) {
         // ... However, command completion mode should not be automatically invoked if this is not the current leading
@@ -214,7 +215,7 @@ QString CommandMode::executeCommand(const QString &commandToExecute)
     static const QRegularExpression reCmds(
         QStringLiteral("^(?:buffer|b|new|vnew|bp|bprev|tabp|tabprev|bn|bnext|tabn|tabnext|bf|bfirst|tabf|tabfirst"
                        "|bl|blast|tabl|tablast|e|edit|tabe|tabedit|tabnew)$"));
-    if (!reCmds.match(cmd.leftRef(cmd.indexOf(QLatin1Char(' ')))).hasMatch()) {
+    if (!reCmds.match(QStringView(cmd).left(cmd.indexOf(QLatin1Char(' ')))).hasMatch()) {
         view()->setFocus();
     }
 
@@ -300,7 +301,8 @@ QString CommandMode::withSedFindTermReplacedWith(const QString &newFindTerm)
     const QString command = m_edit->text();
     ParsedSedExpression parsedSedExpression = parseAsSedExpression();
     Q_ASSERT(parsedSedExpression.parsedSuccessfully);
-    return command.midRef(0, parsedSedExpression.findBeginPos) + newFindTerm + command.midRef(parsedSedExpression.findEndPos + 1);
+    const QStringView strView(command);
+    return strView.mid(0, parsedSedExpression.findBeginPos) + newFindTerm + strView.mid(parsedSedExpression.findEndPos + 1);
 }
 
 QString CommandMode::withSedDelimiterEscaped(const QString &text)
