@@ -61,8 +61,10 @@ void GlobalState::readConfig(const KConfig *configFile)
     m_registers->readConfig(config);
 }
 
-KSharedConfigPtr GlobalState::config() const
+KSharedConfigPtr GlobalState::config()
 {
     // use dummy config for unit tests!
-    return KTextEditor::EditorPrivate::unitTestMode() ? KSharedConfig::openConfig(QStringLiteral("katevirc-unittest"), KConfig::SimpleConfig, QStandardPaths::TempLocation) : KSharedConfig::openConfig(QStringLiteral("katevirc"));
+    return KTextEditor::EditorPrivate::unitTestMode()
+        ? KSharedConfig::openConfig(QStringLiteral("katevirc-unittest"), KConfig::SimpleConfig, QStandardPaths::TempLocation)
+        : KSharedConfig::openConfig(QStringLiteral("katevirc"));
 }
