@@ -17,6 +17,7 @@
 #include "kateviinputmode.h"
 #include <vimode/completionrecorder.h>
 #include <vimode/completionreplayer.h>
+#include <vimode/emulatedcommandbar/emulatedcommandbar.h>
 #include <vimode/inputmodemanager.h>
 #include <vimode/keyparser.h>
 #include <vimode/lastchangerecorder.h>
@@ -344,6 +345,7 @@ bool InsertViMode::handleKeypress(const QKeyEvent *e)
                 return true;
             case Qt::Key_Enter:
             case Qt::Key_Return:
+            case Qt::Key_Tab:
                 if (m_view->completionWidget()->isCompletionActive() && !m_viInputModeManager->macroRecorder()->isReplaying()
                     && !m_viInputModeManager->lastChangeRecorder()->isReplaying()) {
                     m_isExecutingCompletion = true;
@@ -358,6 +360,10 @@ bool InsertViMode::handleKeypress(const QKeyEvent *e)
                         completionFinished();
                         return true;
                     }
+                } else if (m_viInputModeManager->inputAdapter()->viModeEmulatedCommandBar()->isSendingSyntheticSearchCompletedKeypress()) {
+                    // BUG #451076, Do not record/send return for a newline when doing a search via Ctrl+F/Edit->Find menu
+                    m_viInputModeManager->doNotLogCurrentKeypress();
+                    return true;
                 }
                 Q_FALLTHROUGH();
             default:
@@ -577,3 +583,5 @@ void InsertViMode::textInserted(KTextEditor::Document *document, KTextEditor::Ra
         m_textInsertedByCompletionEndPos = range.end();
     }
 }
+
+#include "moc_insertvimode.cpp"
